(function ($) {
    "use strict";
    $(window).on('elementor/frontend/init', () => {
        const addHandler = ($element) => {
            elementorFrontend.elementsHandler.addHandler(rebuiltoSwiperBase, {
                $element,
            });

            if ($element.hasClass('elementor-project-style-4')) {
                let projectSwiper = $element.find('.rebuilto-swiper');
                if (projectSwiper.length) {
                    $(projectSwiper).on('swiperInit', function (e) {
                        let swiperInstance = projectSwiper[0].swiper;

                        if (swiperInstance.params.autoplay.enabled === true) {
                            $element.addClass('auto-start');
                            $element.css({
                                '--playtime': swiperInstance.params.autoplay.delay + 'ms'
                            });
                            swiperInstance.on('autoplayStart', function () {
                                $element.addClass('auto-start');
                                $element.removeClass('auto-stop');
                            });
                            swiperInstance.on('autoplayStop', function () {
                                $element.removeClass('auto-start');
                                $element.addClass('auto-stop');
                            });
                        }

                        let isReversed = false;
                        swiperInstance.on('realIndexChange', function (e) {
                            let previousIndex = this.previousIndex;
                            let activeIndex = this.activeIndex;
                            if (activeIndex < previousIndex) {
                                isReversed = true;
                            } else {
                                isReversed = false;
                            }
                            this.el.classList.toggle("swiper--forwards", isReversed);
                            this.el.classList.toggle("swiper--backwards", !isReversed);
                        }).on('setTransition', function (swiper, duration) {
                            const slides = swiper.slides;
                            slides.forEach(slide => {
                                slide.style.transitionDuration = `${duration}ms`;
                            });

                            if (duration !== 0) {
                                let transitionEnded = false;
                                slides.forEach((slide, index) => {
                                    elementTransitionEnd(slide, () => {
                                        if (transitionEnded) return;
                                        if (!swiper || swiper.destroyed) return;
                                        transitionEnded = true;
                                        swiper.animating = false;
                                        const event = new window.CustomEvent("transitionend", {
                                            bubbles: true,
                                            cancelable: true
                                        });
                                        swiper.wrapperEl.dispatchEvent(event);
                                    });
                                });
                            }
                        }).on('setTranslate', function (swiperInstance, transition) {
                            const {slides} = swiperInstance;
                            const fadeEffectParams = swiperInstance.params.fadeEffect;

                            for (let index = 0; index < slides.length; index++) {
                                const slide = slides[index];
                                let slideOffset = -slide.swiperSlideOffset;
                                if (!swiperInstance.params.virtualTranslate) {
                                    slideOffset -= swiperInstance.translate;
                                }
                                let opacity = 0;
                                const progress = fadeEffectParams.crossFade ? Math.max(1 - Math.abs(slide.progress), 0) : 1 + Math.min(Math.max(slide.progress, -1), 0);
                                const transformElement = slide.querySelector(fadeEffectParams.transformEl);

                                if (transformElement) {
                                    transformElement.style.opacity = progress;
                                }

                                slide.style.transform = `translate3d(${slideOffset}px, ${opacity}px, 0px)`;
                            }
                        });
                    });
                }

            }
        };

        function elementTransitionEnd(element, callback) {
            if (callback) {
                element.addEventListener("transitionend", function transitionEnd(event) {
                    if (event.target === element) {
                        callback.call(element, event);
                        element.removeEventListener("transitionend", transitionEnd);
                    }
                });
            }
        }

        elementorFrontend.hooks.addAction('frontend/element_ready/rebuilto-projects.default', addHandler);
    });
})(jQuery);
