(function ($) {
    "use strict";
    $(window).on('elementor/frontend/init', () => {
        var WidgetHandler = elementorModules.frontend.handlers.Base.extend({
            getDefaultSettings() {
                return {
                    selectors: {
                        mainSlider: '.main-swiper',
                        contentSlider: '.content-swiper',
                    },
                };
            },
            getDefaultElements() {
                const selectors = this.getSettings('selectors');
                return {
                    $swiperMain: this.$element.find(selectors.mainSlider),
                    $swiperContent: this.$element.find(selectors.contentSlider),
                };
            },
            onInit: function () {
                elementorModules.frontend.handlers.Base.prototype.onInit.apply(this, arguments);
                const elementSettings = this.getElementSettings(),
                    slidesToShow = elementSettings.slides_to_show || '4',
                    elementorBreakpoints = elementorFrontend.config.responsive.activeBreakpoints,
                    defaultSlidesToShowMap = {
                        mobile: 1,
                        tablet: 1,
                    };
                const swiperOptions = {
                    slidesPerView: slidesToShow,
                    spaceBetween: 0,
                    handleElementorBreakpoints: true,
                    watchSlidesProgress: true,
                };

                swiperOptions.breakpoints = {};
                let lastBreakpointSlidesToShowValue = slidesToShow;

                Object.keys(elementorBreakpoints).reverse().forEach((breakpointName) => {
                    const defaultSlidesToShow = defaultSlidesToShowMap[breakpointName] ? defaultSlidesToShowMap[breakpointName] : lastBreakpointSlidesToShowValue;
                    swiperOptions.breakpoints[elementorBreakpoints[breakpointName].value] = {
                        slidesPerView: +elementSettings['slides_to_show_' + breakpointName] || defaultSlidesToShow,
                        slidesPerGroup: +elementSettings['slides_to_scroll_' + breakpointName] || 1,
                    };
                    lastBreakpointSlidesToShowValue = +elementSettings['slides_to_show_' + breakpointName] || defaultSlidesToShow;
                });
                var swiperThumbs;
                var asyncSwiper = elementorFrontend.utils.swiper;
                new asyncSwiper(this.elements.$swiperMain, swiperOptions).then((newSwiperThumbsInstance) => {
                    swiperThumbs = newSwiperThumbsInstance;
                    this.handlerSwiperMain(swiperThumbs);
                });
            },
            handlerSwiperMain: function (swiperThumbs) {
                var swiperContentConfig = {
                    spaceBetween: 0,
                    slidesPerView: 1,
                    thumbs: {
                        swiper: swiperThumbs,
                    },
                    // effect: 'fade',
                    // fadeEffect: {crossFade: true},
                    watchSlidesVisibility: true,
                    watchSlidesProgress: true,
                };
                var asyncSwiper = elementorFrontend.utils.swiper;
                new asyncSwiper(this.elements.$swiperContent, swiperContentConfig);
            },
        });

        elementorFrontend.hooks.addAction('frontend/element_ready/rebuilto-timeline-slider.default', function ($scope) {
            elementorFrontend.elementsHandler.addHandler(WidgetHandler, {
                $element: $scope,
            });
        });
    });
})(jQuery);
