<?php
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists('Rebuilto_Customize')) {

    class Rebuilto_Customize {


        public function __construct() {
            add_action('customize_register', array($this, 'customize_register'));
            add_action('wp_enqueue_scripts', [$this, 'customize_custom_css']);
        }


        public function customize_custom_css() {
            $line_color = rebuilto_get_theme_option('line_color', '#e3e3e3');
            $css = '--vertical-line-color:'.$line_color.';';
            $var = "body{{$css}}";
            wp_add_inline_style('rebuilto-style', $var);
        }
        
        /**
         * @param $wp_customize WP_Customize_Manager
         */
        public function customize_register($wp_customize) {

            /**
             * Theme options.
             */
            require_once get_theme_file_path('inc/customize-control/editor.php');
//            require_once get_theme_file_path('inc/customize-control/color.php');
            
            $this->init_rebuilto_blog($wp_customize);

            $this->init_rebuilto_social($wp_customize);

            $this->init_rebuilto_scroll($wp_customize);

            do_action('rebuilto_customize_register', $wp_customize);
        }


        public function init_rebuilto_scroll($wp_customize) {

            $wp_customize->add_section('rebuilto_smooth_scroll', array(
                'title' => esc_html__('Smooth Scroll', 'rebuilto'),
            ));

            $wp_customize->add_setting('rebuilto_options_smooth_scroll', array(
                'type'              => 'option',
                'default'           => '',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rebuilto_options_smooth_scroll', array(
                'type'        => 'radio',
                'section'     => 'rebuilto_smooth_scroll',
                'label'       => esc_html__('Enable', 'rebuilto'),
                'description' => esc_html__('Smooth Scroll On Windows', 'rebuilto'),
                'choices'     => array(
                    ''    => esc_html__('No', 'rebuilto'),
                    'yes' => esc_html__('Yes', 'rebuilto'),
                ),
            ));
        }


        /**
         * @param $wp_customize WP_Customize_Manager
         *
         * @return void
         */
        public function init_rebuilto_blog($wp_customize) {

            $wp_customize->add_section('rebuilto_blog_archive', array(
                'title' => esc_html__('Blog', 'rebuilto'),
            ));

            // =========================================
            // Select Style
            // =========================================

            $wp_customize->add_setting('rebuilto_options_blog_style', array(
                'type'              => 'option',
                'default'           => 'standard',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rebuilto_options_blog_style', array(
                'section' => 'rebuilto_blog_archive',
                'label'   => esc_html__('Blog style', 'rebuilto'),
                'type'    => 'select',
                'choices' => array(
                    'standard' => esc_html__('Blog Standard', 'rebuilto'),
                    //====start_premium
                    'style-1'  => esc_html__('Blog Grid', 'rebuilto'),
                    'list'     => esc_html__('Blog List', 'rebuilto'),
                    //====end_premium
                ),
            ));

            $wp_customize->add_setting('rebuilto_options_blog_columns', array(
                'type'              => 'option',
                'default'           => 1,
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rebuilto_options_blog_columns', array(
                'section' => 'rebuilto_blog_archive',
                'label'   => esc_html__('Colunms', 'rebuilto'),
                'type'    => 'select',
                'choices' => array(
                    1 => esc_html__('1', 'rebuilto'),
                    2 => esc_html__('2', 'rebuilto'),
                    3 => esc_html__('3', 'rebuilto'),
                    4 => esc_html__('4', 'rebuilto'),
                ),
            ));

            $wp_customize->add_setting('rebuilto_options_blog_archive_sidebar', array(
                'type'              => 'option',
                'default'           => 'right',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rebuilto_options_blog_archive_sidebar', array(
                'section' => 'rebuilto_blog_archive',
                'label'   => esc_html__('Sidebar Position', 'rebuilto'),
                'type'    => 'select',
                'choices' => array(
                    'left'  => esc_html__('Left', 'rebuilto'),
                    'right' => esc_html__('Right', 'rebuilto'),
                ),
            ));
        }

        /**
         * @param $wp_customize WP_Customize_Manager
         *
         * @return void
         */
        public function init_rebuilto_social($wp_customize) {

            $wp_customize->add_section('rebuilto_social', array(
                'title' => esc_html__('Socials', 'rebuilto'),
            ));
            $wp_customize->add_setting('rebuilto_options_social_share', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rebuilto_options_social_share', array(
                'type'    => 'checkbox',
                'section' => 'rebuilto_social',
                'label'   => esc_html__('Show Social Share', 'rebuilto'),
            ));
            $wp_customize->add_setting('rebuilto_options_social_share_facebook', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rebuilto_options_social_share_facebook', array(
                'type'    => 'checkbox',
                'section' => 'rebuilto_social',
                'label'   => esc_html__('Share on Facebook', 'rebuilto'),
            ));
            $wp_customize->add_setting('rebuilto_options_social_share_twitter', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rebuilto_options_social_share_twitter', array(
                'type'    => 'checkbox',
                'section' => 'rebuilto_social',
                'label'   => esc_html__('Share on Twitter', 'rebuilto'),
            ));
            $wp_customize->add_setting('rebuilto_options_social_share_linkedin', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rebuilto_options_social_share_linkedin', array(
                'type'    => 'checkbox',
                'section' => 'rebuilto_social',
                'label'   => esc_html__('Share on Linkedin', 'rebuilto'),
            ));
            $wp_customize->add_setting('rebuilto_options_social_share_google-plus', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rebuilto_options_social_share_google-plus', array(
                'type'    => 'checkbox',
                'section' => 'rebuilto_social',
                'label'   => esc_html__('Share on Google+', 'rebuilto'),
            ));

            $wp_customize->add_setting('rebuilto_options_social_share_pinterest', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rebuilto_options_social_share_pinterest', array(
                'type'    => 'checkbox',
                'section' => 'rebuilto_social',
                'label'   => esc_html__('Share on Pinterest', 'rebuilto'),
            ));
            $wp_customize->add_setting('rebuilto_options_social_share_email', array(
                'type'              => 'option',
                'capability'        => 'edit_theme_options',
                'sanitize_callback' => 'sanitize_text_field',
            ));

            $wp_customize->add_control('rebuilto_options_social_share_email', array(
                'type'    => 'checkbox',
                'section' => 'rebuilto_social',
                'label'   => esc_html__('Share on Email', 'rebuilto'),
            ));
        }
    }
}
return new Rebuilto_Customize();
