<?php

use Elementor\Plugin;

if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('Rebuilto_Elementor')) :

    /**
     * The Rebuilto Elementor Integration class
     */
    class Rebuilto_Elementor {
        private $suffix = '';

        public function __construct() {
            $this->suffix = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) ? '' : '.min';

            add_action('wp', [$this, 'register_auto_scripts_frontend']);
            add_action('elementor/elements/categories_registered', [$this, 'register_widget_category']);
            add_action('wp_enqueue_scripts', [$this, 'add_scripts'], 15);
            add_action('elementor/widgets/register', array($this, 'customs_widgets'));
            add_action('elementor/widgets/register', array($this, 'include_widgets'));
            add_action('elementor/frontend/after_enqueue_scripts', [$this, 'add_js']);

            // Custom Animation Scroll
            add_filter('elementor/controls/animations/additional_animations', [$this, 'add_animations_scroll']);

            // Backend
            add_action('elementor/editor/after_enqueue_styles', [$this, 'add_style_editor'], 99);

            // Add Icon Custom
            add_action('elementor/icons_manager/native', [$this, 'add_icons_native']);
            add_action('elementor/controls/controls_registered', [$this, 'add_icons']);

            if (!rebuilto_is_elementor_pro_activated()) {
                require trailingslashit(get_template_directory()) . 'inc/elementor/custom-css.php';
                require trailingslashit(get_template_directory()) . 'inc/elementor/sticky-section.php';
                if (is_admin()) {
                    add_action('manage_elementor_library_posts_columns', [$this, 'admin_columns_headers']);
                    add_action('manage_elementor_library_posts_custom_column', [$this, 'admin_columns_content'], 10, 2);
                }
                require get_theme_file_path('inc/elementor/motion-fx/controls-group.php');
                require get_theme_file_path('inc/elementor/motion-fx/module.php');
            }

            require get_theme_file_path('inc/elementor/modules/page-settings.php');
            if (function_exists('hfe_init')) {
                require get_theme_file_path('inc/elementor/modules/header-settings.php');
            }

            add_filter('elementor/fonts/additional_fonts', [$this, 'additional_fonts']);
            add_action('wp_enqueue_scripts', [$this, 'elementor_kit']);
        }

        public function elementor_kit() {
            $active_kit_id = Elementor\Plugin::$instance->kits_manager->get_active_id();
            Elementor\Plugin::$instance->kits_manager->frontend_before_enqueue_styles();
            $myvals = get_post_meta($active_kit_id, '_elementor_page_settings', true);
            if (!empty($myvals)) {
                $css = '';
                foreach ($myvals['system_colors'] as $key => $value) {
                    $css .= $value['color'] !== '' ? '--' . $value['_id'] . ':' . $value['color'] . ';' : '';
                }

                $var = "body{{$css}}";
                wp_add_inline_style('rebuilto-style', $var);
            }
        }

        public function additional_fonts($fonts) {
            return $fonts;
        }

        public function admin_columns_headers($defaults) {
            $defaults['shortcode'] = esc_html__('Shortcode', 'rebuilto');

            return $defaults;
        }

        public function admin_columns_content($column_name, $post_id) {
            if ('shortcode' === $column_name) {
                ob_start();
                ?>
                <input class="elementor-shortcode-input" type="text" readonly onfocus="this.select()" value="[hfe_template id='<?php echo esc_attr($post_id); ?>']"/>
                <?php
                ob_get_contents();
            }
        }

        public function add_js() {
            $suffix = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) ? '' : '.min';
            wp_enqueue_script('rebuilto-elementor-frontend', get_theme_file_uri('/assets/js/elementor-frontend'. $suffix . '.js'), [], REBUILTO_VERSION);
        }

        public function add_style_editor() {

            wp_enqueue_style('rebuilto-elementor-editor-icon', get_theme_file_uri('/assets/css/admin/elementor/icons.css'), [], REBUILTO_VERSION);
        }

        public function add_scripts() {

            $suffix = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) ? '' : '.min';
            wp_enqueue_style('rebuilto-elementor', get_template_directory_uri() . '/assets/css/base/elementor.css', '', REBUILTO_VERSION);
            wp_style_add_data('rebuilto-elementor', 'rtl', 'replace');

            // Add Scripts

            $e_swiper_latest     = Plugin::$instance->experiments->is_feature_active('e_swiper_latest');
            $e_swiper_asset_path = $e_swiper_latest ? 'assets/lib/swiper/v8/' : 'assets/lib/swiper/';
            $e_swiper_version    = $e_swiper_latest ? '8.4.5' : '5.3.6';
            wp_register_script(
                'swiper',
                plugins_url('elementor/' . $e_swiper_asset_path . 'swiper.js', 'elementor'),
                [],
                $e_swiper_version,
                true
            );
        }

        public function register_auto_scripts_frontend() {
            $suffix = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) ? '' : '.min';
            wp_register_script('rebuilto-elementor-swiper', get_theme_file_uri('/assets/js/elementor-swiper' . $suffix . '.js'), array('jquery', 'elementor-frontend'), REBUILTO_VERSION, true);
            // Register auto scripts frontend

            $files  = glob(get_theme_file_path('/assets/js/elementor/*' . $suffix . '.js'));
            foreach ($files as $file) {
                $file_name = wp_basename($file);
                $handle    = str_replace($suffix.".js", '', $file_name);
                $scr       = get_theme_file_uri('/assets/js/elementor/' . $file_name);
                if (file_exists($file)) {
                    wp_register_script('rebuilto-elementor-' . $handle, $scr, ['jquery', 'elementor-frontend'], REBUILTO_VERSION, true);
                }
            }
        }

        public function register_widget_category($this_cat) {
            $this_cat->add_category(
                'rebuilto-addons',
                [
                    'title' => esc_html__('Rebuilto Addons', 'rebuilto'),
                    'icon'  => 'fa fa-plug',
                ]
            );
            return $this_cat;
        }

        public function add_animations_scroll($animations) {
            $animations['Rebuilto Animation'] = [
                'opal-move-up'    => 'Move Up',
                'opal-move-down'  => 'Move Down',
                'opal-move-left'  => 'Move Left',
                'opal-move-right' => 'Move Right',
                'opal-flip'       => 'Flip',
                'opal-helix'      => 'Helix',
                'opal-scale-up'   => 'Scale',
                'opal-am-popup'   => 'Popup',
            ];

            return $animations;
        }

        public function customs_widgets() {
            $files = glob(get_theme_file_path('/inc/elementor/custom-widgets/*.php'));
            foreach ($files as $file) {
                if (file_exists($file)) {
                    require_once $file;
                }
            }
        }

        /**
         * @param $widgets_manager Elementor\Widgets_Manager
         */
        public function include_widgets($widgets_manager) {
            require 'base-swiper-widget.php';
            $files = glob(get_theme_file_path('/inc/elementor/widgets/*.php'));
            foreach ($files as $file) {
                if (file_exists($file)) {
                    require_once $file;
                }
            }
        }

        public function add_icons( $manager ) {
            $new_icons = json_decode( '{"rebuilto-icon-angle-down":"angle-down","rebuilto-icon-angle-left":"angle-left","rebuilto-icon-angle-right":"angle-right","rebuilto-icon-angle-up":"angle-up","rebuilto-icon-arrow-left":"arrow-left","rebuilto-icon-arrow-right":"arrow-right","rebuilto-icon-arrow-triangel":"arrow-triangel","rebuilto-icon-arrow-up-right":"arrow-up-right","rebuilto-icon-award":"award","rebuilto-icon-blueprint":"blueprint","rebuilto-icon-brickwall":"brickwall","rebuilto-icon-building":"building","rebuilto-icon-buildings":"buildings","rebuilto-icon-chat":"chat","rebuilto-icon-check":"check","rebuilto-icon-circle-check":"circle-check","rebuilto-icon-compass":"compass","rebuilto-icon-construction":"construction","rebuilto-icon-crane":"crane","rebuilto-icon-download":"download","rebuilto-icon-earth":"earth","rebuilto-icon-engineer":"engineer","rebuilto-icon-floor":"floor","rebuilto-icon-helmet":"helmet","rebuilto-icon-house":"house","rebuilto-icon-innovation":"innovation","rebuilto-icon-mail-inbox":"mail-inbox","rebuilto-icon-minus-1":"minus-1","rebuilto-icon-navigation":"navigation","rebuilto-icon-phone":"phone","rebuilto-icon-plus-1":"plus-1","rebuilto-icon-quote":"quote","rebuilto-icon-safety":"safety","rebuilto-icon-spades":"spades","rebuilto-icon-star-sharp":"star-sharp","rebuilto-icon-trophy":"trophy","rebuilto-icon-trust":"trust","rebuilto-icon-user-group":"user-group","rebuilto-icon-360":"360","rebuilto-icon-bars":"bars","rebuilto-icon-cart-empty":"cart-empty","rebuilto-icon-check-square":"check-square","rebuilto-icon-chevron-down":"chevron-down","rebuilto-icon-chevron-left":"chevron-left","rebuilto-icon-chevron-right":"chevron-right","rebuilto-icon-chevron-up":"chevron-up","rebuilto-icon-circle":"circle","rebuilto-icon-cloud-download-alt":"cloud-download-alt","rebuilto-icon-comment":"comment","rebuilto-icon-comments":"comments","rebuilto-icon-contact":"contact","rebuilto-icon-credit-card":"credit-card","rebuilto-icon-dot-circle":"dot-circle","rebuilto-icon-edit":"edit","rebuilto-icon-envelope":"envelope","rebuilto-icon-expand-alt":"expand-alt","rebuilto-icon-external-link-alt":"external-link-alt","rebuilto-icon-file-alt":"file-alt","rebuilto-icon-file-archive":"file-archive","rebuilto-icon-folder-open":"folder-open","rebuilto-icon-folder":"folder","rebuilto-icon-frown":"frown","rebuilto-icon-gift":"gift","rebuilto-icon-grid":"grid","rebuilto-icon-grip-horizontal":"grip-horizontal","rebuilto-icon-heart-fill":"heart-fill","rebuilto-icon-history":"history","rebuilto-icon-home":"home","rebuilto-icon-info-circle":"info-circle","rebuilto-icon-instagram":"instagram","rebuilto-icon-level-up-alt":"level-up-alt","rebuilto-icon-list":"list","rebuilto-icon-map-marker-check":"map-marker-check","rebuilto-icon-meh":"meh","rebuilto-icon-minus-circle":"minus-circle","rebuilto-icon-minus":"minus","rebuilto-icon-mobile-android-alt":"mobile-android-alt","rebuilto-icon-money-bill":"money-bill","rebuilto-icon-pencil-alt":"pencil-alt","rebuilto-icon-plus":"plus","rebuilto-icon-random":"random","rebuilto-icon-reply-all":"reply-all","rebuilto-icon-reply":"reply","rebuilto-icon-search":"search","rebuilto-icon-shield-check":"shield-check","rebuilto-icon-shopping-basket":"shopping-basket","rebuilto-icon-sign-out-alt":"sign-out-alt","rebuilto-icon-smile":"smile","rebuilto-icon-spinner":"spinner","rebuilto-icon-square":"square","rebuilto-icon-star":"star","rebuilto-icon-store":"store","rebuilto-icon-sync":"sync","rebuilto-icon-tachometer-alt":"tachometer-alt","rebuilto-icon-thumbtack":"thumbtack","rebuilto-icon-ticket":"ticket","rebuilto-icon-times-circle":"times-circle","rebuilto-icon-times-square":"times-square","rebuilto-icon-times":"times","rebuilto-icon-trophy-alt":"trophy-alt","rebuilto-icon-truck":"truck","rebuilto-icon-video":"video","rebuilto-icon-wishlist-empty":"wishlist-empty","rebuilto-icon-adobe":"adobe","rebuilto-icon-amazon":"amazon","rebuilto-icon-android":"android","rebuilto-icon-angular":"angular","rebuilto-icon-apper":"apper","rebuilto-icon-apple":"apple","rebuilto-icon-atlassian":"atlassian","rebuilto-icon-behance":"behance","rebuilto-icon-bitbucket":"bitbucket","rebuilto-icon-bitcoin":"bitcoin","rebuilto-icon-bity":"bity","rebuilto-icon-bluetooth":"bluetooth","rebuilto-icon-btc":"btc","rebuilto-icon-centos":"centos","rebuilto-icon-chrome":"chrome","rebuilto-icon-codepen":"codepen","rebuilto-icon-cpanel":"cpanel","rebuilto-icon-discord":"discord","rebuilto-icon-dochub":"dochub","rebuilto-icon-docker":"docker","rebuilto-icon-dribbble":"dribbble","rebuilto-icon-dropbox":"dropbox","rebuilto-icon-drupal":"drupal","rebuilto-icon-ebay":"ebay","rebuilto-icon-facebook-f":"facebook-f","rebuilto-icon-facebook":"facebook","rebuilto-icon-figma":"figma","rebuilto-icon-firefox":"firefox","rebuilto-icon-google-plus":"google-plus","rebuilto-icon-google":"google","rebuilto-icon-grunt":"grunt","rebuilto-icon-gulp":"gulp","rebuilto-icon-html5":"html5","rebuilto-icon-joomla":"joomla","rebuilto-icon-link-brand":"link-brand","rebuilto-icon-linkedin":"linkedin","rebuilto-icon-mailchimp":"mailchimp","rebuilto-icon-opencart":"opencart","rebuilto-icon-paypal":"paypal","rebuilto-icon-pinterest-p":"pinterest-p","rebuilto-icon-reddit":"reddit","rebuilto-icon-skype":"skype","rebuilto-icon-slack":"slack","rebuilto-icon-snapchat":"snapchat","rebuilto-icon-spotify":"spotify","rebuilto-icon-trello":"trello","rebuilto-icon-twitter":"twitter","rebuilto-icon-vimeo":"vimeo","rebuilto-icon-whatsapp":"whatsapp","rebuilto-icon-wordpress":"wordpress","rebuilto-icon-yoast":"yoast","rebuilto-icon-youtube":"youtube"}', true );
			$icons     = $manager->get_control( 'icon' )->get_settings( 'options' );
			$new_icons = array_merge(
				$new_icons,
				$icons
			);
			// Then we set a new list of icons as the options of the icon control
			$manager->get_control( 'icon' )->set_settings( 'options', $new_icons ); 
        }

        public function add_icons_native($tabs) {

            $tabs['opal-custom'] = [
                'name'          => 'rebuilto-icon',
                'label'         => esc_html__('Rebuilto Icon', 'rebuilto'),
                'prefix'        => 'rebuilto-icon-',
                'displayPrefix' => 'rebuilto-icon-',
                'labelIcon'     => 'fab fa-font-awesome-alt',
                'ver'           => REBUILTO_VERSION,
                'fetchJson'     => get_theme_file_uri('/inc/elementor/icons.json'),
                'native'        => true,
            ];

            return $tabs;
        }
    }

endif;

return new Rebuilto_Elementor();
