<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;

class Rebuilto_Elementor_Awards_Box extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve awardsbox widget name.
     *
     * @return string Widget name.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'rebuilto-awards-box';
    }

    /**
     * Get widget title.
     *
     * Retrieve awardsbox widget title.
     *
     * @return string Widget title.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Rebuilto Awards Box', 'rebuilto');
    }

    /**
     * Get widget icon.
     *
     * Retrieve awardsbox widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-person';
    }

    public function get_script_depends() {
        return ['magnific-popup', 'rebuilto-elementor-awards-box', 'rebuilto-elementor-swiper'];
    }

    public function get_style_depends() {
        return ['magnific-popup'];
    }

    public function get_categories() {
        return array('rebuilto-addons');
    }

    /**
     * Register awardsbox widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'section_awards',
            [
                'label' => esc_html__('Awards', 'rebuilto'),
            ]
        );
        $repeater = new Repeater();


        $repeater->add_control(
            'awardsbox_image',
            [
                'label'      => esc_html__('Choose Image', 'rebuilto'),
                'default'    => [
                    'url' => Elementor\Utils::get_placeholder_image_src(),
                ],
                'type'       => Controls_Manager::MEDIA,
                'show_label' => false,
            ]
        );

        $repeater->add_control(
            'awardsbox_year',
            [
                'label'   => esc_html__('Year', 'rebuilto'),
                'default' => '2024',
                'type'    => Controls_Manager::TEXT,
            ]
        );

        $repeater->add_control(
            'awardsbox_name',
            [
                'label'   => esc_html__('Name', 'rebuilto'),
                'default' => 'Name Awards',
                'type'    => Controls_Manager::TEXT,
            ]
        );

        $repeater->add_control(
            'awardsbox_description',
            [
                'label'       => esc_html__('Description', 'rebuilto'),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'rebuilto'),
            ]
        );

        $repeater->add_control(
            'button_text',
            [
                'label' => esc_html__('Button Text', 'rebuilto'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Learn more', 'rebuilto'),
            ]
        );

        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'rebuilto'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'rebuilto'),
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->add_control(
            'awardsbox',
            [
                'label'       => esc_html__('Items', 'rebuilto'),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{{ name }}}',
            ]
        );

        $this->add_control(
            'awardsbox_layout',
            [
                'label'              => esc_html__('Layout', 'rebuilto'),
                'type'               => Controls_Manager::SELECT,
                'default'            => '1',
                'options'            => [
                    '1' => esc_html__('Layout 1', 'rebuilto'),
                    '2' => esc_html__('Layout 2', 'rebuilto'),
                ],
                'frontend_available' => true,
                'render_type'        => 'template',
                'prefix_class'       => 'awardsbox-layout-',
            ]
        );

        $this->add_group_control(
            Elementor\Group_Control_Image_Size::get_type(),
            [
                'name'      => 'awardsbox_image',
                'default'   => 'full',
                'separator' => 'none',
            ]
        );

        $this->add_responsive_control(
            'column',
            [
                'label'     => esc_html__('Columns', 'rebuilto'),
                'type'      => \Elementor\Controls_Manager::SELECT,
                'default'   => 1,
                'options'   => [1 => 1, 2 => 2, 3 => 3, 4 => 4],
                'selectors' => [
                    '{{WRAPPER}} .d-grid' => 'grid-template-columns: repeat({{VALUE}}, 1fr)',
                ],
            ]
        );

        $this->add_responsive_control(
            'awardsbox_gutter',
            [
                'label'      => esc_html__('Gutter', 'rebuilto'),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .d-grid' => 'grid-gap:{{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render awardsbox widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        if (empty($settings['awardsbox'])) {
            return;
        }

        $this->add_render_attribute('wrapper', 'class', 'elementor-awardsbox-item-wrapper');
        $this->add_render_attribute('row', 'class', 'layout-' . esc_attr($settings['awardsbox_layout']));
        $this->add_render_attribute('row', 'class', 'd-grid');
        $this->add_render_attribute('item', 'class', 'elementor-awardsbox-item grid-item');
        $image_html = '';
        ?>

        <div <?php $this->print_render_attribute_string('wrapper'); ?>>
            <div class="elementor-awardsbox-wrapper-inner">
                <div <?php $this->print_render_attribute_string('row'); ?>>
                    <?php foreach ($settings['awardsbox'] as $index => $awardsbox): ?>
                        <div <?php $this->print_render_attribute_string('item'); ?> data-goto="<?php echo esc_attr($index); ?>">
                            <div class="awardsbox-item-inner">
                                <?php
                                if ($settings['awardsbox_layout'] !== '2') {
                                    $this->render_image($settings, $awardsbox);
                                }
                                ?>
                                <div class="awards-content">

                                    <?php if ($awardsbox['awardsbox_year']) { ?>
                                        <div class="awards-year"><span><?php echo esc_html($awardsbox['awardsbox_year']); ?></span></div>
                                    <?php } ?>
                                    <div class="awards-content-header">
                                        <a href="<?php echo esc_attr($awardsbox['link']['url']) ?>">
                                            <?php
                                            echo '<div class="awards-name">' . esc_html($awardsbox['awardsbox_name']) . '</div>';
                                            ?>
                                        </a>
                                        <?php if ($awardsbox['awardsbox_description']) { ?>
                                            <div class="awards-description"><?php echo wp_kses_post($awardsbox['awardsbox_description']); ?></div>
                                        <?php } ?>
                                    </div>
                                    <div class="awards-more-link-wrap style-link">
                                        <a class="awards-more-link" href="<?php echo esc_attr($awardsbox['link']['url']) ?>">
                                            <?php if (!empty($awardsbox['button_text'])) : ?>
                                                <i class="rebuilto-icon-arrow-up-right"></i>
                                                <span><?php echo esc_html($awardsbox['button_text']);?></span>
                                            <?php endif; ?>
                                        </a>
                                    </div>
                                </div>

                            </div>
                        </div>
                        <?php
                        if ($settings['awardsbox_layout'] == '2') {
                            ob_start();
                            ?>
                            <div class="swiper-slide">
                                <?php $this->render_image($settings, $awardsbox); ?>
                            </div>
                            <?php
                            $image_html .= ob_get_clean();
                        }
                     endforeach; ?>
                </div>
                <?php
                if ($settings['awardsbox_layout'] == '2') {
                    ?>
                    <div class="awards-effect">
                        <div class="rebuilto-swiper swiper swiper-awards-effect">
                            <div class="swiper-wrapper">
                                <?php printf('%s', $image_html); ?>
                            </div>
                        </div>
                    </div>
                    <?php
                }
                ?>
            </div>
        </div>
        <?php
    }

    private function render_image($settings, $awardsbox) {
        if (!empty($awardsbox['awardsbox_image']['url'])) :
            ?>
            <div class="awards-image">
                <?php
                $awardsbox['awardsbox_image_size']             = $settings['awardsbox_image_size'];
                $awardsbox['awardsbox_image_custom_dimension'] = $settings['awardsbox_image_custom_dimension'];
                echo Group_Control_Image_Size::get_attachment_image_html($awardsbox, 'awardsbox_image');
                ?>
            </div>
        <?php
        endif;
    }

}

$widgets_manager->register(new Rebuilto_Elementor_Awards_Box());
