<?php

namespace Elementor;

use Elementor\Core\Kits\Documents\Tabs\Global_Typography;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class Rebuilto_Elementor_HotSpots extends Widget_Base {

    public function get_name() {
        return 'rebuilto-hotspot';
    }

    public function get_title() {
        return esc_html__('Rebuilto Hot Spots', 'rebuilto');
    }

    public function get_icon() {
        return 'eicon-hotspot';
    }

    public function get_categories() {
        return array('rebuilto-addons');
    }

    protected function register_controls() {


        $this->start_controls_section('hotspot_image_section',
            [
                'label' => esc_html__('Image', 'rebuilto'),
            ]
        );

        $this->add_control('hotspot_image',
            [
                'label'       => __('Choose Image', 'rebuilto'),
                'type'        => Controls_Manager::MEDIA,
                'default'     => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'    => 'background_image', // Actually its `image_size`.
                'default' => 'full'
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section('image_hotspot_icons_settings',
            [
                'label' => esc_html__('Hotspots', 'rebuilto'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'hotspot_text',
            [
                'label'   => esc_html__('Text', 'rebuilto'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->add_responsive_control(
                'hotspot_main_icons_horizontal_position',
            [
                'label'      => esc_html__('Horizontal Position', 'rebuilto'),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                    'em' => [
                        'min' => 0,
                        'max' => 20,
                    ],
                ],
                'default'    => [
                    'size' => 50,
                    'unit' => '%'
                ],
                'selectors'  => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'left: {{SIZE}}{{UNIT}}'
                ]
            ]
        );

        $repeater->add_responsive_control(
                'hotspot_main_icons_vertical_position',
            [
                'label'      => esc_html__('Vertical Position', 'rebuilto'),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                    'em' => [
                        'min' => 0,
                        'max' => 20,
                    ],
                ],
                'default'    => [
                    'size' => 50,
                    'unit' => '%'
                ],
                'selectors'  => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'top: {{SIZE}}{{UNIT}}'
                ]
            ]
        );

        $this->add_control('image_hotspot_icons',
            [
                'label'  => esc_html__('Hotspots', 'rebuilto'),
                'type'   => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section('image_lookbook_image_style_settings',
            [
                'label' => esc_html__('Main Image', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'height',
            [
                'label'      => esc_html__('Height', 'rebuilto'),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', 'rem', 'vh', 'custom'],
                'range'      => [
                    'px' => [
                        'min' => 100,
                        'max' => 1000,
                    ],
                    'vh' => [
                        'min' => 10,
                        'max' => 100,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .rebuilto-addons-image-lookbook-ib-img' => 'min-height: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'image_lookbook_image_padding',
            [
                'label'      => esc_html__('Padding', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .rebuilto-image-lookbook-container .rebuilto-addons-image-lookbook-ib-img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->add_responsive_control(
            'image_lookbook_border_radius',
            [
                'label'      => esc_html__('Border Radius', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .rebuilto-image-lookbook-container .rebuilto-addons-image-lookbook-ib-img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section('image_lookbook_hotspots_style_settings',
            [
                'label' => esc_html__('Hotspots', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'hotspots_width',
            [
                'label'      => esc_html__('Width', 'rebuilto'),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em', 'rem', 'vw', 'custom'],
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                    '%'  => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .hotspot-dots' => 'width: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'hotspots_height',
            [
                'label'      => esc_html__('Height', 'rebuilto'),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em', 'rem', 'vw', 'custom'],
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                    '%'  => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .hotspot-dots' => 'height: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_control(
            'hotspots_bg',
            [
                'label'     => esc_html__('Background Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .hotspot-dots' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .hotspot-dots:after' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section('image_lookbook_text_style_settings',
            [
                'label' => esc_html__('Text', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'text_position',
            [
                'label'      => esc_html__('Position', 'rebuilto'),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'custom'],
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                    '%'  => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .hotspot-item .hotspot-text' => 'bottom: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->end_controls_section();
    }


    protected function render() {
        // get our input from the widget settings.
        $settings  = $this->get_settings_for_display();
        $image_src = $settings['hotspot_image'];

        $image_src_size = Group_Control_Image_Size::get_attachment_image_src($image_src['id'], 'background_image', $settings);
        if (empty($image_src_size)) {
            $image_src_size = $image_src['url'];
        }

        ?>
        <div id="rebuilto-image-lookbook-<?php echo esc_attr($this->get_id()); ?>" class="rebuilto-image-lookbook-container" >
            <img class="rebuilto-addons-image-lookbook-ib-img" alt="Background" src="<?php echo esc_url($image_src_size); ?>">
            <?php foreach ($settings['image_hotspot_icons'] as $index => $item) {
                $list_item_key = 'img_hotspot_' . $index;
                $this->add_render_attribute($list_item_key, 'class',
                    [
                        'elementor-repeater-item-' . $item['_id'],
                        'hotspot-wrapper',
                    ]);
                ?>
                <div <?php $this->print_render_attribute_string($list_item_key); ?>>
                    <div class="hotspot-item">
                        <?php if ($item['hotspot_text']) { ?>
                            <div class="hotspot-text">
                                <?php echo esc_html($item["hotspot_text"]) ?>
                            </div>
                            <div class="hotspot-dots"></div>
                        <?php } ?>
                    </div>
                </div>
            <?php } ?>
        </div>

        <?php
    }
}

$widgets_manager->register(new Rebuilto_Elementor_HotSpots());