<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Repeater;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Image_Size;
class Rebuilto_Elementor_IconboxCarousel extends Rebuilto_Base_Widgets_Swiper {
    /**
     * Get widget name.
     *
     * Retrieve iconbox widget name.
     *
     * @return string Widget name.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'rebuilto-iconbox-carousel';
    }

    /**
     * Get widget title.
     *
     * Retrieve iconbox widget title.
     *
     * @return string Widget title.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Rebuilto Iconbox Carousel', 'rebuilto');
    }

    /**
     * Get widget icon.
     *
     * Retrieve iconbox widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-carousel';
    }

    public function get_script_depends() {
        return ['rebuilto-elementor-iconbox-carousel', 'rebuilto-elementor-swiper'];
    }

    public function get_categories() {
        return array('rebuilto-addons');
    }

    public function on_export($element) {
        unset($element['settings']['box_image']['id']);

        return $element;
    }

    /**
     * Register iconbox widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'section_iconbox',
            [
                'label' => esc_html__('Iconbox Carousel', 'rebuilto'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'box_type',
            [
                'label'   => esc_html__('Type', 'rebuilto'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'box_icon',
                'options' => [
                    'box_img' => esc_html__('Image', 'rebuilto'),
                    'box_icon'  => esc_html__('Icon', 'rebuilto'),
                ]
            ]
        );

        $repeater->add_control(
            'selected_icon',
            [
                'label'     => esc_html__('Icon', 'rebuilto'),
                'type'      => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'   => [
                    'value'   => 'fas fa-star',
                    'library' => 'fa-solid',
                ],
                'condition' => [
                    'box_type' => 'box_icon'
                ]
            ]
        );

        $repeater->add_control(
            'box_image',
            [
                'label'      => esc_html__('Choose Image', 'rebuilto'),
                'default'    => [
                    'url' => Elementor\Utils::get_placeholder_image_src(),
                ],
                'type'       => Controls_Manager::MEDIA,
                'show_label' => false,
                'condition'  => [
                    'box_type' => 'box_img'
                ]
            ]
        );

        $repeater->add_control(
            'iconbox_title',
            [
                'label'   => esc_html__('Title', 'rebuilto'),
                'type'    => Controls_Manager::TEXT,
                'default'     => '',
            ]
        );

        $repeater->add_control(
            'iconbox_content',
            [
                'label'       => esc_html__('Content', 'rebuilto'),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => 'Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.',
                'label_block' => true,
                'rows'        => '10',
            ]
        );

        $repeater->add_control(
            'iconbox_button',
            [
                'label' => esc_html__( 'Button Text', 'rebuilto' ),
                'type' => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => esc_html__( 'Click Here', 'rebuilto' ),
                'separator' => 'before',
            ]
        );

        $repeater->add_control(
            'iconbox_link',
            [
                'label'       => esc_html__('Link to', 'rebuilto'),
                'type'        => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                ],
                'placeholder' => esc_html__('https://your-link.com', 'rebuilto'),
            ]
        );

        $this->add_control(
            'iconbox-carousel',
            [
                'label'       => esc_html__('Items', 'rebuilto'),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{{ iconbox_title }}}',
            ]
        );

        $this->add_group_control(
            Elementor\Group_Control_Image_Size::get_type(),
            [
                'name'      => 'box_image',
                'default'   => 'full',
                'separator' => 'none',
            ]
        );

        $this->add_responsive_control(
            'column',
            [
                'label'        => esc_html__('Columns', 'rebuilto'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'      => 1,
                'options'      => [1 => 1, 2 => 2, 3 => 3, 4 => 4, 5 => 5, 6 => 6],
                'selectors' => [
                    '{{WRAPPER}} .d-grid' => 'grid-template-columns: repeat({{VALUE}}, 1fr)',
                ],
                'condition' => ['enable_carousel!' => 'yes']
            ]
        );

        $this->add_responsive_control(
            'gutter',
            [
                'label'      => esc_html__('Gutter', 'rebuilto'),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .d-grid' => 'grid-gap:{{SIZE}}{{UNIT}}',
                ],
                'condition'  => ['enable_carousel!' => 'yes']
            ]
        );

        $this->add_responsive_control(
            'iconbox_alignment',
            [
                'label'       => esc_html__('Alignment', 'rebuilto'),
                'type'        => Controls_Manager::CHOOSE,
                'options'     => [
                    'left'   => [
                        'title' => esc_html__('Left', 'rebuilto'),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'rebuilto'),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__('Right', 'rebuilto'),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'label_block' => false,
                'render_type'        => 'template',
                'default'      => 'left',
                'selectors'   => [
                    '{{WRAPPER}} .elementor-iconbox-item' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'enable_carousel',
            [
                'label' => esc_html__('Enable Carousel', 'rebuilto'),
                'type'  => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'view',
            [
                'label'   => esc_html__('View', 'rebuilto'),
                'type'    => Controls_Manager::HIDDEN,
                'default' => 'traditional',
            ]
        );
        $this->end_controls_section();


        // WRAPPER STYLE
        $this->start_controls_section(
            'section_style_iconbox_wrapper',
            [
                'label' => esc_html__('Wrapper', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,

            ]
        );

        $this->add_responsive_control(
            'max-height',
            [
                'label' => esc_html__( 'Height', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', 'rem', 'vh', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 100,
                        'max' => 1000,
                    ],
                    'vh' => [
                        'min' => 10,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .grid-item .elementor-icon-box-wrapper' => 'min-height: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'box-alignment',
            [
                'label' => esc_html__( 'Alignment', 'rebuilto' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'rebuilto' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'rebuilto' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'rebuilto' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}} .grid-item .elementor-icon-box-wrapper' => 'text-align: {{VALUE}}',
                ],

            ]
        );

        $this->add_responsive_control(
            'margin_box',
            [
                'label'      => esc_html__('Margin Wrapper', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-iconbox-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'padding_iconbox_wrapper',
            [
                'label'      => esc_html__('Padding Item', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .grid-item .elementor-icon-box-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'margin_iconbox_wrapper',
            [
                'label'      => esc_html__('Margin Item', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .grid-item .elementor-icon-box-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'background_iconbox_wrapper',
            [
                'label' => esc_html__( 'Background Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .grid-item .elementor-icon-box-wrapper' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'wrapper_border',
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => '{{WRAPPER}} .grid-item .elementor-icon-box-wrapper',
                'separator'   => 'before',
            ]
        );

        $this->add_control(
            'wrapper_radius',
            [
                'label'      => esc_html__('Border Radius', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .grid-item .elementor-icon-box-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        // icon style

        $this->start_controls_section(
            'section_style_icon',
            [
                'label' => esc_html__( 'Icon', 'rebuilto' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => esc_html__( 'Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'global' => [
                    'default' => Global_Colors::COLOR_PRIMARY,
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon' => 'fill: {{VALUE}}; color: {{VALUE}}; border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_space',
            [
                'label' => esc_html__( 'Spacing', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_size',
            [
                'label' => esc_html__( 'Size', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 6,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        // Content style
        $this->start_controls_section(
            'section_style_iconbox_content',
            [
                'label' => esc_html__('Content', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'content_color',
            [
                'label'     => esc_html__('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon-box-description' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'content_color_hover',
            [
                'label'     => esc_html__('Color Hover', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-iconbox-item-wrapper:hover .elementor-icon-box-description' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'content_typography',
                'selector' => '{{WRAPPER}} .grid-item .elementor-icon-box-description',
            ]
        );

        $this->add_responsive_control(
            'content_spacing',
            [
                'label'      => esc_html__('Margin', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-icon-box-description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();


        // Title.
        $this->start_controls_section(
            'section_style_iconbox_title',
            [
                'label' => esc_html__('Title', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_text_color',
            [
                'label'     => esc_html__('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon-box-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_text_color_hover',
            [
                'label'     => esc_html__('Color Hover', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon-box-wrapper:hover .elementor-icon-box-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .elementor-icon-box-title',
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'size_units' => ['px', 'em', '%'],
                'label'      => esc_html__('Spacing', 'rebuilto'),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-icon-box-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'readmore_style',
            [
                'label' => esc_html__('Read More', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs( 'readmore_color_tabs' );

        $this->start_controls_tab( 'readmore_colors_normal',
            [
                'label' => esc_html__( 'Normal', 'rebuilto' ),
            ]
        );
        $this->add_control(
            'readmore_color',
            [
                'label'     => esc_html__('Text Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .more-link-wrap a.more-link' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'readmore_background',
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .more-link-wrap a.more-link',
                'fields_options' => [
                    'background' => [
                        'default' => 'classic',
                    ],
                    'color' => [
                        'dynamic' => [],
                    ],
                    'color_b' => [
                        'dynamic' => [],
                    ],
                ],
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'readmore_colors_hover',
            [
                'label' => esc_html__( 'Hover', 'rebuilto' ),
            ]
        );
        $this->add_control(
            'readmore_color_hover',
            [
                'label'     => esc_html__('Text Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .more-link-wrap a.more-link:hover' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'readmore_background_hover',
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'fields_options' => [
                    'background' => [
                        'default' => 'classic',
                    ],
                    'color' => [
                        'dynamic' => [],
                    ],
                    'color_b' => [
                        'dynamic' => [],
                    ],
                ],
                'selector' => '{{WRAPPER}} .more-link-wrap a.more-link:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        // Carousel options
        $this->add_control_carousel(['enable_carousel' => 'yes']);

    }

    /**
     * Render iconbox widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        if (!empty($settings['iconbox-carousel']) && is_array($settings['iconbox-carousel'])) {
            $this->add_render_attribute('wrapper', 'class', 'elementor-iconbox-item-wrapper');
            $this->add_render_attribute('row', 'class', 'alignment-' . esc_attr($settings['iconbox_alignment']));
            // Carousel
            $this->get_data_elementor_columns();
            // Item
            $this->add_render_attribute('item', 'class', 'elementor-iconbox-item');

            $migrated = isset( $settings['__fa4_migrated']['selected_icon'] );
            $is_new = empty( $settings['icon'] ) && Icons_Manager::is_migration_allowed();
            $count = 0;
            ?>

            <div <?php $this->print_render_attribute_string('wrapper'); // WPCS: XSS ok. ?>>
                <div <?php $this->print_render_attribute_string('row'); // WPCS: XSS ok. ?>>
                    <?php foreach ($settings['iconbox-carousel'] as $iconbox):
                        $count ++;
                        ?>
                        <div <?php $this->print_render_attribute_string('item'); // WPCS: XSS ok. ?> data-count="<?php printf('%02d',$count);?>">
                            <div class="elementor-icon-box-wrapper">
                                <div class="elementer-icon-box-inner">
                                <?php if ($iconbox['box_type'] == 'box_img') { ?>
                                    <?php $this->render_image($settings, $iconbox); ?>
                                <?php } ?>

                                <?php if ($iconbox['box_type'] == 'box_icon') { ?>
                                <?php if (!empty($iconbox['icon']) || !empty($iconbox['selected_icon']['value'])) : ?>
                                    <div class="elementor-icon-box-icon">
                                    <span class="elementor-icon">
                                        <?php if ($is_new || $migrated) :
                                            Elementor\Icons_Manager::render_icon($iconbox['selected_icon'], ['aria-hidden' => 'true']);
                                        else : ?>
                                            <i class="<?php echo esc_attr($iconbox['icon']); ?>" aria-hidden="true"></i>
                                        <?php endif; ?>
                                    </span>
                                    </div>
                                <?php endif; ?>
                                <?php }
                                ?>
                                <div class="elementor-icon-box-content elementor-button-type-outline elementor-widget-rebuilto-button">
                                    <?php if ($iconbox['iconbox_title']) { ?>
                                        <a href="<?php echo esc_url($iconbox['iconbox_link']['url']); ?>"><h5 class="elementor-icon-box-title"><?php echo sprintf('%s', $iconbox['iconbox_title']); ?></h5></a>
                                    <?php } ?>
                                    <?php if (!empty($iconbox['iconbox_content'])) { ?>
                                        <p class="elementor-icon-box-description"><?php echo sprintf('%s', $iconbox['iconbox_content']); ?></p>
                                    <?php } ?>
                                    <?php if ($iconbox['iconbox_button']) { ?>
                                        <div class="elementor-button elementor-button-link">
                                            <?php $iconbox_name_html = $iconbox['iconbox_button'];
                                            if (!empty($iconbox['iconbox_link']['url'])) {
                                                $iconbox_name_html = '<a class="elementor-button-text" data-name="' . esc_html($iconbox_name_html) . '" href="' . esc_url($iconbox['iconbox_link']['url']) . '">' . '<span>' . esc_html($iconbox_name_html) . '</span>' . '<i class="rebuilto-icon-arrow-up-right"></i></a>';
                                            }
                                            printf('%s', $iconbox_name_html);
                                            ?>
                                        </div>
                                    <?php } ?>
                                </div>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
            <?php $this->render_swiper_pagination_navigation();?>
            <?php
        }
    }

    private function render_image($settings, $iconbox) {
        if (!empty($iconbox['box_image']['url'])) :
            ?>
            <div class="box-image">
                <a href="<?php echo esc_url($iconbox['iconbox_link']['url']); ?>">
                <?php
                $iconbox['box_image_size']             = $settings['box_image_size'];
                $iconbox['box_image_custom_dimension'] = $settings['box_image_custom_dimension'];
                echo Group_Control_Image_Size::get_attachment_image_html($iconbox, 'box_image');
                ?>
                </a>
            </div>
        <?php
        endif;
    }

}

$widgets_manager->register(new Rebuilto_Elementor_IconboxCarousel());

