<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Repeater;
use Elementor\Icons_Manager;
use Elementor\Utils;

class Rebuilto_Elementor_Price_Table extends Elementor\Widget_Base
{

    public function get_name()
    {
        return 'rebuilto-price-table';
    }

    public function get_title()
    {
        return esc_html__('Rebuilto Price Table', 'rebuilto');
    }

    public function get_categories()
    {
        return array('rebuilto-addons');
    }

    public function get_icon()
    {
        return 'eicon-price-table';
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'section_header',
            [
                'label' => esc_html__('Wrap', 'rebuilto'),
            ]
        );
        $this->add_control(
                'pricing_image',
            [
                'label'       => __('Choose Image', 'rebuilto'),
                'type'        => Controls_Manager::MEDIA,
                'default'     => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'    => 'pricing_image',
                'default' => 'full'
            ]
        );

        $this->add_control(
            'heading',
            [
                'label' => esc_html__('Title', 'rebuilto'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__('Pricing Table', 'rebuilto'),
            ]
        );

        $this->add_control(
            'subheading',
            [
                'label' => esc_html__('Sub Title', 'rebuilto'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__('Sub Pricing Table', 'rebuilto'),
            ]
        );

        $this->add_control('heading_pricing', [
            'label' => esc_html__('Pricing', 'rebuilto'),
            'type' => Controls_Manager::HEADING,
            'separator' => 'before',
        ]);

        $this->add_control(
            'currency',
            [
                'label' => esc_html__('Price', 'rebuilto'),
                'type' => Controls_Manager::NUMBER,
                'default' => '39.99',
            ]
        );

        $this->add_control(
            'symbol',
            [
                'label' => esc_html__('symbol', 'rebuilto'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('$', 'rebuilto'),
                'placeholder' => esc_html__('symbol ...', 'rebuilto'),
            ]
        );

        $this->add_control(
            'period',
            [
                'label' => esc_html__('Period', 'rebuilto'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('per month', 'rebuilto'),
                'placeholder' => esc_html__('Period ...', 'rebuilto'),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_features',
            [
                'label' => esc_html__('Features', 'rebuilto'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'item_text',
            [
                'label' => esc_html__('Text', 'rebuilto'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('List Item', 'rebuilto'),
            ]
        );

        $repeater->add_control(
            'item_description',
            [
                'label' => esc_html__('description', 'rebuilto'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Description Item', 'rebuilto'),
            ]
        );

        $repeater->add_control(
            'show_disable',
            [
                'label' => esc_html__('Disable', 'rebuilto'),
                'type'  => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'features_list',
            [
                'type' => Controls_Manager::REPEATER,
                'label' => esc_html__('Items List', 'rebuilto'),
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'item_text' => esc_html__('List Item #1', 'rebuilto'),
                        'item_description' => esc_html__('List Item Description #1', 'rebuilto'),
                    ],
                    [
                        'item_text' => esc_html__('List Item #2', 'rebuilto'),
                        'item_description' => esc_html__('List Item Description #2', 'rebuilto'),
                    ],
                    [
                        'item_text' => esc_html__('List Item #3', 'rebuilto'),
                        'item_description' => esc_html__('List Item Description #3', 'rebuilto'),
                    ],
                ],
                'title_field' => '{{{ item_text }}}',
            ]
        );


        $this->add_control(
            'features_selected_icon',
            [
                'label' => esc_html__( 'Icon', 'rebuilto' ),
                'type' => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default' => [
                    'value' => 'fas fa-star',
                    'library' => 'fa-solid',
                ],
            ]
        );


        $this->add_control(
            'button_text',
            [
                'label' => esc_html__('Button Text', 'rebuilto'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Click Here', 'rebuilto'),
            ]
        );

        $this->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'rebuilto'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'rebuilto'),
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->end_controls_section();


        // WRAPPER STYLE
        $this->start_controls_section(
            'section_style_price_wrapper',
            [
                'label' => esc_html__('Wrapper', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,

            ]
        );

        $this->add_responsive_control(
            'padding_price_wrapper',
            [
                'label'      => esc_html__('Padding', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .price_table_inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'margin_price_wrapper',
            [
                'label'      => esc_html__('Margin', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .price_table_inner' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'color_price_wrapper',
            [
                'label'     => esc_html__('Background Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .price_table_inner' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'wrapper_border',
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => '{{WRAPPER}} .price_table_inner',
                'separator'   => 'before',
            ]
        );

        $this->add_control(
            'wrapper_radius',
            [
                'label'      => esc_html__('Border Radius', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .price_table_inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'wrapper_box_shadow',
                'selector' => '{{WRAPPER}} .price_table_inner',
            ]
        );

        $this->end_controls_section();

        // header style
        $this->start_controls_section(
            'section_header_style',
            [
                'label' => esc_html__('Header', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'header_style_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => esc_html__( 'Title', 'rebuilto' ),

            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .price_table_header .title',
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => esc_html__( 'Spacing', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .price_table_header .title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'header_style_subtitle',
            [
                'type' => Controls_Manager::HEADING,
                'label' => esc_html__( 'SubTitle', 'rebuilto' ),
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .price_table_header .subtitle',
            ]
        );

        $this->add_responsive_control(
            'subtitle_spacing',
            [
                'label' => esc_html__( 'Spacing', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .price_table_header .subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'header_price',
            [
                'label' => esc_html__('Price', 'rebuilto'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'price_typography',
                'selector' => '{{WRAPPER}} .price_table_header .elementor-price-table__currency',
            ]
        );

        $this->add_responsive_control(
            'header_price_spacing',
            [
                'label' => esc_html__( 'Spacing', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .price_table_header .elementor-price-table__currency' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'header_symbol',
            [
                'type' => Controls_Manager::HEADING,
                'label' => esc_html__('Symbol', 'rebuilto'),
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'symbol_typography',
                'selector' => '{{WRAPPER}} .price_table_header .elementor-price-table__integer-part',
            ]
        );

        $this->add_responsive_control(
            'header_symbol_spacing',
            [
                'label' => esc_html__( 'Spacing', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .price_table_header .elementor-price-table__integer-part' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'header_period',
            [
                'type' => Controls_Manager::HEADING,
                'label' => esc_html__('Period', 'rebuilto'),
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'period_typography',
                'selector' => '{{WRAPPER}} .price_table_header .elementor-price-table__period',
            ]
        );

        $this->add_responsive_control(
            'header_padding',
            [
                'label'      => esc_html__('Header Padding', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'separator' => 'before',
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .price_table_header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'heading_content_colors',
            [
                'type' => Controls_Manager::HEADING,
                'label' => esc_html__( 'Colors', 'rebuilto' ),
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs( 'price_color_tabs' );

        $this->start_controls_tab( 'price_colors_normal',
            [
                'label' => esc_html__( 'Normal', 'rebuilto' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'subtitle_color',
            [
                'label' => esc_html__( 'Sub Title Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subtitle' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'price_color',
            [
                'label' => esc_html__( 'Price Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-table__currency' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .elementor-price-table__integer-part' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'period_color',
            [
                'label' => esc_html__( 'Period Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-table__period' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pricing_bgcolor',
            [
                'label' => esc_html__('Background Color', 'rebuilto'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .price_table_header' => 'background-color: {{VALUE}};'
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'price_colors_hover',
            [
                'label' => esc_html__( 'Hover', 'rebuilto' ),
            ]
        );


        $this->add_control(
            'title_color_hover',
            [
                'label' => esc_html__( 'Title Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price_table_inner:hover .title' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'subtitle_color_hover',
            [
                'label' => esc_html__( 'Sub Title Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price_table_inner:hover .subtitle' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'price_color_hover',
            [
                'label' => esc_html__( 'Price Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price_table_inner:hover .elementor-price-table__currency' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .price_table_inner:hover .elementor-price-table__integer-part' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'period_color_hover',
            [
                'label' => esc_html__( 'Period Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price_table_inner:hover .elementor-price-table__period' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'pricing_bgcolor_hover',
            [
                'label' => esc_html__('Background Color Hover', 'rebuilto'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .price_table_inner:hover .price_table_header' => 'background-color: {{VALUE}};'
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();


        $this->start_controls_section(
            'content_style',
            [
                'label' => esc_html__( 'Content', 'rebuilto' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_control(
            'features_style_icon',
            [
                'type' => Controls_Manager::HEADING,
                'label' => esc_html__( 'Features Icon', 'rebuilto' ),
                'condition' => [
                    'features_selected_icon[value]!' => '',
                ],
            ]
        );


        $this->add_responsive_control(
            'features_icon_spacing',
            [
                'label' => esc_html__( 'Spacing', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', 'rem', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} ul li .features-icon' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'features_selected_icon[value]!' => '',
                ],
            ]
        );

        $this->add_control(
            'features_icon_color',
            [
                'label' => esc_html__( 'Icon Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} ul li .features-icon svg' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} ul li .features-icon i' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'features_selected_icon[value]!' => '',
                ],
            ]
        );

        $this->add_control(
            'features_icon_border_color',
            [
                'label' => esc_html__( 'Border Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} ul li .features-icon' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'features_selected_icon[value]!' => '',
                ],
            ]
        );

        $this->add_control(
            'features_style_text',
            [
                'type' => Controls_Manager::HEADING,
                'label' => esc_html__( 'Features Text', 'rebuilto' ),

            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'features_text_typography',
                'selector' => '{{WRAPPER}} .elementor-price-table__features-list .elementor-inline-editing .elementor-item-text',
            ]
        );

        $this->add_control(
            'features_text_color',
            [
                'label' => esc_html__( ' Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-table__features-list .elementor-inline-editing .elementor-item-text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'features_text_spacing',
            [
                'label' => esc_html__( 'Spacing', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em', 'rem', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-table__features-list .elementor-inline-editing .elementor-item-text' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'features_style_description',
            [
                'type' => Controls_Manager::HEADING,
                'label' => esc_html__( 'Features Description', 'rebuilto' ),

            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'features_description_typography',
                'selector' => '{{WRAPPER}} .elementor-price-table__features-list .elementor-inline-editing .elementor-item-description',
            ]
        );

        $this->add_control(
            'features_description_color',
            [
                'label' => esc_html__( ' Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-price-table__features-list .elementor-inline-editing .elementor-item-description' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_margin',
            [
                'label'      => esc_html__('Margin Content', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-price-table__features-list' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'button_footer_style',
            [
                'label' => esc_html__( 'Button', 'rebuilto' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'button_typography',
                'selector' => '{{WRAPPER}} .elementor-price-table__button .button-more-link',
            ]
        );


        $this->start_controls_tabs( 'button_color_tabs' );

        $this->start_controls_tab( 'button_colors_normal',
            [
                'label' => esc_html__( 'Normal', 'rebuilto' ),
            ]
        );

        $this->add_control(
            'button_color',
            [
                'label' => esc_html__( 'Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .button-more-link' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_bgcolor',
            [
                'label' => esc_html__('Background Color', 'rebuilto'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .button-more-link' => 'background-color: {{VALUE}};',

                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'button_colors_hover',
            [
                'label' => esc_html__( 'Hover', 'rebuilto' ),
            ]
        );

        $this->add_control(
            'button_color_hover',
            [
                'label' => esc_html__( 'Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .button-more-link:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_bgcolor_hover',
            [
                'label' => esc_html__('Background Color', 'rebuilto'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .button-more-link:hover' => 'background-color: {{VALUE}};'
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_responsive_control(
            'button_padding',
            [
                'label'      => esc_html__('Button Padding', 'rebuilto'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .button-more-link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
            'button_style',
            [
                'label' => esc_html__('Button Style', 'rebuilto'),
                'type'  => Controls_Manager::SWITCHER,
                'prefix_class' => 'price-button-style-',
            ]
        );

        $this->add_responsive_control(
            'mask_width',
            [
                'label' => esc_html__( 'Mask Width', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}.price-button-style-yes .button-more-link:hover:after' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'button_style' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'mask_background_color',
            [
                'label'     => esc_html__('Mask Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}.price-button-style-yes .button-more-link:after' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'button_style' => 'yes',
                ],
            ]
        );


        $this->add_responsive_control(
            'icon_spacing_hover',
            [
                'label' => esc_html__( 'Icon Spacing Hover', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}.price-button-style-yes .button-more-link:hover i' => 'transform: translateX({{SIZE}}{{UNIT}});',
                ],
                'condition' => [
                    'button_style' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $image_src = $settings['pricing_image'];

        $icon_tag = 'span';

        if ( ! isset( $settings['icon'] ) && ! Icons_Manager::is_migration_allowed() ) {
            // add old default
            $settings['icon'] = 'fa fa-star';
        }

        $has_icon = ! empty( $settings['icon'] );

        if ( ! empty( $settings['link']['url'] ) ) {
            $icon_tag = 'a';

            $this->add_link_attributes( 'link', $settings['link'] );
        }

        if ( $has_icon ) {
            $this->add_render_attribute( 'i', 'class', $settings['icon'] );
            $this->add_render_attribute( 'i', 'aria-hidden', 'true' );
        }

        $image_src_size = Group_Control_Image_Size::get_attachment_image_src($image_src['id'], 'pricing_image', $settings);
        if (empty($image_src_size)) {
            $image_src_size = $image_src['url'];
        }

        $this->add_render_attribute('wrapper', 'class', 'elementor-price-table-item-wrapper');
        $this->add_render_attribute('features-list-item', 'class', 'price-table-features-list-item');

        if ( ! $has_icon && ! empty( $settings['selected_icon']['value'] ) || ! empty( $settings['features_selected_icon']['value'] ) ) {
            $has_icon = true;
        }
        $migrated = isset( $settings['__fa4_migrated']['selected_icon'] );
        $is_new = ! isset( $settings['icon'] ) && Icons_Manager::is_migration_allowed();
        ?>

        <div <?php $this->print_render_attribute_string('wrapper'); ?>>
            <div class="price_table_inner">
                <div class="price_table_header">
                    <img class="price_table_image" alt="Background" src="<?php echo esc_url($image_src_size); ?>">
                    <?php if (!empty($settings['heading'])) : ?>
                        <div class="title"><?php echo esc_html($settings["heading"]) ?></div>
                    <?php endif; ?>
                    <?php if (!empty($settings['subheading'])) : ?>
                        <div class="subtitle"><?php echo esc_html($settings["subheading"]) ?></div>
                    <?php endif; ?>
                    <div class="elementor-price-table__price">
                        <span class="elementor-price-table__integer-part"><?php echo esc_html($settings['symbol']); ?></span>
                        <span class="elementor-price-table__currency"><?php echo esc_html($settings['currency']); ?></span>
                        <span class="elementor-price-table__period"><?php echo esc_html($settings['period']); ?></span>
                    </div>
                </div>

                <?php if (!empty($settings['features_list'])) :?>
                    <ul class="elementor-price-table__features-list">
                        <?php foreach ($settings['features_list'] as $index => $item) :
                            if (!empty($item['show_disable'] === 'yes')) {
                                $this->add_render_attribute('features-list-item', 'class', 'features-list-item-disable');
                                $this->add_render_attribute('features-list-item', 'class', 'elementor-repeater-item-' . $item['_id']);
                            }?>
                            <li  <?php $this->print_render_attribute_string('features-list-item'); ?>>
                                <?php if ( $has_icon ) : ?>
                                    <div class="features-icon">
                                        <?php if ( $is_new || $migrated ) :
                                            Icons_Manager::render_icon( $settings['features_selected_icon'], [ 'aria-hidden' => 'true' ] );
                                        else : ?>
                                            <i <?php $this->print_render_attribute_string( 'icon' ); ?>></i>
                                        <?php endif; ?>
                                    </div>
                                <?php endif; ?>
                                <div class="elementor-inline-editing">
                                    <div class="elementor-item-text">
                                        <?php if (!empty($item['item_text'])) : echo esc_html($item['item_text']); endif; ?>
                                    </div>
                                    <div class="elementor-item-description">
                                        <?php if (!empty($item['item_description'])) : echo esc_html($item['item_description']); endif; ?>
                                    </div>
                                </div>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                <?php endif; ?>

                <div class="elementor-price-table__button">
                    <a class="button-more-link elementor-button btn-theme" href="<?php echo esc_attr($settings['link']['url']) ?>">
                        <?php if (!empty($settings['button_text'])) : ?>
                            <span class="elementor-button-content-wrapper">
                                <span><?php echo esc_html($settings['button_text']);?></span>
                                <i class="rebuilto-icon-long-arrow-right" aria-hidden="true"></i>
                            </span>
                        <?php endif; ?>
                    </a>
                </div>
            </div>
        </div>
        <?php
    }
}

$widgets_manager->register(new Rebuilto_Elementor_Price_Table());
