<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Utils;

use Elementor\Icons_Manager;


/**
 * Elementor tabs widget.
 *
 * Elementor widget that displays vertical or horizontal tabs with different
 * pieces of content.
 *
 * @since 1.0.0
 */
class Rebuilto_Elementor_Scroll_Features extends Elementor\Widget_Base {

    public function get_categories() {
        return array('opal-addons');
    }

    /**
     * Get widget name.
     *
     * Retrieve tabs widget name.
     *
     * @return string Widget name.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'rebuilto-scroll-features';
    }

    /**
     * Get widget title.
     *
     * Retrieve tabs widget title.
     *
     * @return string Widget title.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_title() {
        return __('Rebuilto Scroll Features', 'rebuilto');
    }

    /**
     * Get widget icon.
     *
     * Retrieve tabs widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-tabs';
    }

    public function get_script_depends() {
        return ['rebuilto-elementor-scroll-features'];
    }

    /**
     * Register tabs widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'section_tabs',
            [
                'label' => __('Scroll Features', 'rebuilto'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control('scroll_features_number', [
            'label'       => __('Number', 'rebuilto'),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
        ]);

        $repeater->add_control(
            'features_image',
            [
                'label'   => esc_html__('Choose Image', 'rebuilto'),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );


        $repeater->add_control('scroll_features_heading', [
            'label'       => __('Heading & Content', 'rebuilto'),
            'type'        => Controls_Manager::TEXT,
            'default'     => __('Scroll Features Heading', 'rebuilto'),
            'placeholder' => __('Scroll Features Heading', 'rebuilto'),
            'label_block' => true,
        ]);

        $repeater->add_control('scroll_features_content', [
            'label'       => __('Content', 'rebuilto'),
            'default'     => __('Scroll Features Content', 'rebuilto'),
            'placeholder' => __('Scroll Features Content', 'rebuilto'),
            'type'        => Controls_Manager::WYSIWYG,
            'show_label'  => false,
        ]);

        $repeater->add_control(
            'features_icon',
            [
                'label' => esc_html__( 'Icon', 'rebuilto' ),
                'type' => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default' => [
                    'value' => 'fas fa-star',
                    'library' => 'fa-solid',
                ],
            ]
        );

        $repeater->add_control(
            'features_button',
            [
                'label' => esc_html__( 'Button Text', 'rebuilto' ),
                'type' => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => esc_html__( 'Click Here', 'rebuilto' ),
                'separator' => 'before',
            ]
        );

        $repeater->add_control(
            'features_link',
            [
                'label'       => esc_html__('Link to', 'rebuilto'),
                'placeholder' => esc_html__('https://your-link.com', 'rebuilto'),
                'type'        => Controls_Manager::URL,
            ]
        );

        $this->add_control(
            'featuress',
            [
                'label'   => __('Scroll Features Items', 'rebuilto'),
                'type'    => Controls_Manager::REPEATER,
                'fields'  => $repeater->get_controls(),
                'default' => [
                    [
                        'scroll_features_number'    => __('01', 'rebuilto'),
                        'scroll_features_subheading'    => __('Subheading', 'rebuilto'),
                        'scroll_features_heading' => __('Heading #1', 'rebuilto'),
                        'scroll_features_content' => __('I am features content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'rebuilto'),
                    ],
                    [
                        'scroll_features_number'    => __('02', 'rebuilto'),
                        'scroll_features_subheading'    => __('Subheading', 'rebuilto'),
                        'scroll_features_heading' => __('Heading #2', 'rebuilto'),
                        'scroll_features_content' => __('I am features content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'rebuilto'),
                    ],
                    [
                        'scroll_features_number'    => __('03', 'rebuilto'),
                        'scroll_features_subheading'    => __('Subheading', 'rebuilto'),
                        'scroll_features_heading' => __('Heading #3', 'rebuilto'),
                        'scroll_features_content' => __('I am features content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'rebuilto'),
                    ],
                ],

                'title_field' => '{{{ scroll_features_heading }}}',
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'      => 'features_image',
                'default'   => 'full',
                'separator' => 'none',
            ]
        );


        $this->add_responsive_control(
            'effect_offset',
            [
                'label'     => esc_html__('Effect Offset', 'rebuilto'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}' => '--offset: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_title_style',
            [
                'label' => __('Title', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control( 'tabs_width', [
            'label' => esc_html__( 'Width', 'rebuilto' ),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                '%' => [
                    'min' => 10,
                    'max' => 50,
                ],
                'px' => [
                    'min' => 20,
                    'max' => 600,
                ],
            ],
            'default' => [
                'unit' => '%',
            ],
            'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
            'selectors' => [
                '{{WRAPPER}}' => '--n-features-title-width: {{SIZE}}{{UNIT}}',
            ],

        ] );


        $this->add_responsive_control( 'features_title_space_between', [
            'label' => esc_html__( 'Gap between', 'rebuilto' ),
            'type' => Controls_Manager::SLIDER,
            'size_units' => [ 'px', 'em', 'rem', 'custom' ],
            'range' => [
                'px' => [
                    'max' => 400,
                ],
                'em' => [
                    'max' => 40,
                ],
                'rem' => [
                    'max' => 40,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}}' => '--n-features-title-gap: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $this->add_responsive_control( 'features_title_spacing', [
            'label' => esc_html__( 'Distance from content', 'rebuilto' ),
            'type' => Controls_Manager::SLIDER,
            'size_units' => [ 'px', 'em', 'rem', 'custom' ],
            'range' => [
                'px' => [
                    'max' => 400,
                ],
                'em' => [
                    'max' => 40,
                ],
                'rem' => [
                    'max' => 40,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}}' => '--n-features-gap: {{SIZE}}{{UNIT}}',
            ],
        ] );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_number_style',
            [
                'label' => __('Number', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'number_typography',
                'selector' => '{{WRAPPER}} .scroll-features-heading .features-number',
            ]
        );

        $this->start_controls_tabs('tabs_number_style');

        $this->start_controls_tab(
            'tab_number_normal',
            [
                'label' => __('Normal', 'rebuilto'),
            ]
        );

        $this->add_control(
            'number_color',
            [
                'label'     => __('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-features-heading .features-number' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_number_active',
            [
                'label' => __('Active', 'rebuilto'),
            ]
        );

        $this->add_control(
            'number_color_active',
            [
                'label'     => __('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-features-title-item .scroll-features-heading.active .features-number' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'section_heading_style',
            [
                'label' => __('Heading', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'heading_typography',
                'selector' => '{{WRAPPER}} .scroll-features-heading',
            ]
        );

        $this->add_control(
            'heading_color',
            [
                'label'     => __('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-features-heading' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->add_control(
            'heading_color_active',
            [
                'label'     => __('Color Active', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-features-title-item .scroll-features-heading.active' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->add_responsive_control(
            'spacing_heading',
            [
                'label'     => __('Spacing', 'rebuilto'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .scroll-features-heading .features-number' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        // icon style

        $this->start_controls_section(
            'section_style_icon',
            [
                'label' => esc_html__( 'Icon', 'rebuilto' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => esc_html__( 'Color', 'rebuilto' ),
                'type' => Controls_Manager::COLOR,

                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-features-icon .elementor-icon' => 'fill: {{VALUE}}; color: {{VALUE}}; border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_space',
            [
                'label' => esc_html__( 'Spacing', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .scroll-features-icon .elementor-icon' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_size',
            [
                'label' => esc_html__( 'Size', 'rebuilto' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 6,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .scroll-features-icon .elementor-icon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();



        $this->start_controls_section(
            'section_desc_style',
            [
                'label' => __('Desc', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'desc_typography',
                'selector' => '{{WRAPPER}} .scroll-features-desc',
            ]
        );

        $this->add_control(
            'desc_color',
            [
                'label'     => __('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-features-desc' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


    }

    protected function get_html_wrapper_class() {
        return 'elementor-widget-scroll-features elementor-widget-' . $this->get_name();
    }

    /**
     * Render tabs widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();

        $migrated = isset( $settings['__fa4_migrated']['features_icon'] );
        $is_new = empty( $settings['icon'] ) && Icons_Manager::is_migration_allowed();
        ?>
        <div class="scroll-features">
            <div class="scroll-features-list">
                <div class="scroll-features-title">
                    <?php foreach ($settings['featuress'] as $index => $item) :
                        $item_title_setting_key = $this->get_repeater_setting_key('item_title', 'items', $index);
                        $this->add_render_attribute($item_title_setting_key, [
                            'class'         => [
                                'scroll-features-title-item',
                                'features-repeater-item-' . $item['_id']
                            ],
                        ]);
                    ?>
                        <div <?php $this->print_render_attribute_string($item_title_setting_key); ?>>
                            <a href="<?php echo('#scroll-features-content-' . $item['_id']) ?>" class="scroll-features-heading"><span class="features-number"><?php echo esc_html($item['scroll_features_number']); ?></span><?php echo esc_html($item['scroll_features_heading']); ?></a>
                        </div>

                    <?php endforeach; ?>
                </div>
                <div class="scroll-features-content">
                    <?php foreach ($settings['featuress'] as $index => $item) :
                        $item_content_setting_key = $this->get_repeater_setting_key('item_content', 'items', $index);
                        $this->add_render_attribute($item_content_setting_key, [
                                'id'=>['scroll-features-content-' . $item['_id']],
                            'class'         => [
                                'scroll-features-content-item',
                                'features-repeater-item-' . $item['_id']
                            ],
                        ]);
                        ?>
                        <div <?php $this->print_render_attribute_string($item_content_setting_key); ?>>
                            <div class="features-content-item">
                                <div class="scroll-features-image">
                                    <?php $this->render_image($settings, $item); ?>
                                </div>
                                <div class="scroll-features-info">
                                    <?php if (!empty($item['features_icon']['value'])) : ?>
                                        <div class="scroll-features-icon">
                                            <span class="features-icon elementor-icon">
                                                <?php if ($is_new || $migrated) :
                                                    Elementor\Icons_Manager::render_icon($item['features_icon'], ['aria-hidden' => 'true']);
                                                else : ?>
                                                    <i class="<?php echo esc_attr($item['icon']); ?>" aria-hidden="true"></i>
                                                <?php endif; ?>
                                            </span>
                                        </div>
                                    <?php endif; ?>

                                    <div class="scroll-features-desc">
                                        <?php echo do_shortcode($item['scroll_features_content']); ?>
                                    </div>
                                    <?php if ($item['features_button']) { ?>
                                        <div class="scroll-features-button">
                                            <?php $features_name_html = $item['features_button'];
                                            if (!empty($item['features_link']['url'])) {
                                                $features_name_html = '<a class="button-style" data-name="' . esc_html($features_name_html) . '" href="' . esc_url($item['features_link']['url']) . '">' . '<span>' . esc_html($features_name_html) . '</span>' . '<i class="rebuilto-icon-arrow-up-right"></i></a>';
                                            }
                                            printf('%s', $features_name_html);
                                            ?>
                                        </div>
                                    <?php } ?>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
        <?php
    }
    private function render_image($settings, $item) {
        if (!empty($item['features_image']['url'])) :
            ?>
            <?php
            $item['features_image_size']             = $settings['features_image_size'];
            $item['features_image_custom_dimension'] = $settings['features_image_custom_dimension'];
            echo Group_Control_Image_Size::get_attachment_image_html($item, 'features_image');
            ?>
        <?php
        endif;
    }
}

$widgets_manager->register(new Rebuilto_Elementor_Scroll_Features());
