<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Utils;


/**
 * Elementor tabs widget.
 *
 * Elementor widget that displays vertical or horizontal tabs with different
 * pieces of content.
 *
 * @since 1.0.0
 */
class Rebuilto_Elementor_Scroll_Timeline extends Elementor\Widget_Base {

    public function get_categories() {
        return array('opal-addons');
    }

    /**
     * Get widget name.
     *
     * Retrieve tabs widget name.
     *
     * @return string Widget name.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'rebuilto-scroll-timeline';
    }

    /**
     * Get widget title.
     *
     * Retrieve tabs widget title.
     *
     * @return string Widget title.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_title() {
        return __('Rebuilto Scroll Timeline', 'rebuilto');
    }

    /**
     * Get widget icon.
     *
     * Retrieve tabs widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-tabs';
    }

    public function get_script_depends() {
        return ['rebuilto-elementor-scroll-timeline'];
    }

    /**
     * Register tabs widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'section_tabs',
            [
                'label' => __('Scroll Timeline', 'rebuilto'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control('scroll_timeline_number', [
            'label'       => __('Number', 'rebuilto'),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
        ]);

        $repeater->add_control('scroll_timeline_subheading', [
            'label'       => __('Subheading', 'rebuilto'),
            'type'        => Controls_Manager::TEXT,
            'default'     => __('Subheading', 'rebuilto'),
            'placeholder' => __('Subheading', 'rebuilto'),
            'label_block' => true,
        ]);

        $repeater->add_control('scroll_timeline_heading', [
            'label'       => __('Heading & Content', 'rebuilto'),
            'type'        => Controls_Manager::TEXT,
            'default'     => __('Scroll Timeline Heading', 'rebuilto'),
            'placeholder' => __('Scroll Timeline Heading', 'rebuilto'),
            'label_block' => true,
        ]);

        $repeater->add_control('scroll_timeline_content', [
            'label'       => __('Content', 'rebuilto'),
            'default'     => __('Scroll Timeline Content', 'rebuilto'),
            'placeholder' => __('Scroll Timeline Content', 'rebuilto'),
            'type'        => Controls_Manager::WYSIWYG,
            'show_label'  => false,
        ]);


        $repeater->add_control(
            'timeline_image',
            [
                'label'   => esc_html__('Choose Image', 'rebuilto'),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );


        $this->add_control(
            'timelines',
            [
                'label'   => __('Scroll Timeline Items', 'rebuilto'),
                'type'    => Controls_Manager::REPEATER,
                'fields'  => $repeater->get_controls(),
                'default' => [
                    [
                        'scroll_timeline_number'    => __('01', 'rebuilto'),
                        'scroll_timeline_subheading'    => __('Subheading', 'rebuilto'),
                        'scroll_timeline_heading' => __('Heading #1', 'rebuilto'),
                        'scroll_timeline_content' => __('I am timeline content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'rebuilto'),
                    ],
                    [
                        'scroll_timeline_number'    => __('02', 'rebuilto'),
                        'scroll_timeline_subheading'    => __('Subheading', 'rebuilto'),
                        'scroll_timeline_heading' => __('Heading #2', 'rebuilto'),
                        'scroll_timeline_content' => __('I am timeline content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'rebuilto'),
                    ],
                    [
                        'scroll_timeline_number'    => __('03', 'rebuilto'),
                        'scroll_timeline_subheading'    => __('Subheading', 'rebuilto'),
                        'scroll_timeline_heading' => __('Heading #3', 'rebuilto'),
                        'scroll_timeline_content' => __('I am timeline content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'rebuilto'),
                    ],
                ],

                'title_field' => '{{{ scroll_timeline_heading }}}',
            ]
        );


        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'      => 'timeline_image',
                'default'   => 'full',
                'separator' => 'none',
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_wrapper_style',
            [
                'label' => __('Wrapper', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'height_wrapper',
            [
                'label'     => __('Height', 'rebuilto'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-item' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->add_responsive_control(
            'padding_wrapper',
            [
                'label' => esc_html__( 'Padding', 'rebuilto' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_subheading_style',
            [
                'label' => __('Subheading', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'subheading_typography',
                'selector' => '{{WRAPPER}} .scroll-timeline-subheading',
            ]
        );

        $this->add_responsive_control(
            'spacing_subheading',
            [
                'label'     => __('Spacing', 'rebuilto'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-item:not(:last-child) .scroll-timeline-subheading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs('tabs_subheading_style');

        $this->start_controls_tab(
            'tab_subheading_normal',
            [
                'label' => __('Normal', 'rebuilto'),
            ]
        );

        $this->add_control(
            'subheading_color',
            [
                'label'     => __('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-subheading' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_subheading_hover',
            [
                'label' => __('Hover', 'rebuilto'),
            ]
        );

        $this->add_control(
            'subheading_color_hover',
            [
                'label'     => __('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-subheading:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_subheading_active',
            [
                'label' => __('Active', 'rebuilto'),
            ]
        );

        $this->add_control(
            'subheading_color_active',
            [
                'label'     => __('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-item.timeline-active .scroll-timeline-subheading' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();


        $this->start_controls_section(
            'section_number_style',
            [
                'label' => __('Number', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'number_typography',
                'selector' => '{{WRAPPER}} .scroll-timeline-number .timeline-number',
            ]
        );

        $this->start_controls_tabs('tabs_number_style');

        $this->start_controls_tab(
            'tab_number_normal',
            [
                'label' => __('Normal', 'rebuilto'),
            ]
        );

        $this->add_control(
            'number_color',
            [
                'label'     => __('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-number .timeline-number' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'number_bg_color',
            [
                'label'     => __('Background Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-number .timeline-number' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_number_active',
            [
                'label' => __('Active', 'rebuilto'),
            ]
        );

        $this->add_control(
            'number_color_active',
            [
                'label'     => __('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-item.timeline-active .scroll-timeline-number .timeline-number' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'number_bg_color_active',
            [
                'label'     => __('Background Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-item.timeline-active .scroll-timeline-number .timeline-number' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'section_heading_style',
            [
                'label' => __('Heading', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'heading_typography',
                'selector' => '{{WRAPPER}} .scroll-timeline-heading',
            ]
        );

        $this->add_control(
            'heading_color',
            [
                'label'     => __('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-heading' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'spacing_heading',
            [
                'label'     => __('Spacing', 'rebuilto'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_desc_style',
            [
                'label' => __('Desc', 'rebuilto'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'desc_typography',
                'selector' => '{{WRAPPER}} .scroll-timeline-desc',
            ]
        );

        $this->add_control(
            'desc_color',
            [
                'label'     => __('Color', 'rebuilto'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .scroll-timeline-desc' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


    }

    protected function get_html_wrapper_class() {
        return 'elementor-widget-scroll-timeline elementor-widget-' . $this->get_name();
    }

    /**
     * Render tabs widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="scroll-timeline">
            <div class="scroll-timeline-inner">
                <div class="timeline-content-image">

                </div>
                <div class="scroll-timeline-list">
                    <?php foreach ($settings['timelines'] as $index => $item) :
                        $item_content_setting_key = $this->get_repeater_setting_key('item_content', 'items', $index);
                        $this->add_render_attribute($item_content_setting_key, [
                            'class'         => [
                                'scroll-timeline-item',
                                ($index == 0) ? 'timeline-active' : '',
                                'timeline-repeater-item-' . $item['_id']
                            ],
                        ]);
                        ?>
                        <div <?php $this->print_render_attribute_string($item_content_setting_key); ?>>
                            <div class="scroll-timeline-image">
                                <?php $this->render_image($settings, $item); ?>
                            </div>
                            <div class="scroll-timeline-number"><div class="timeline-number"><span><?php echo esc_html($item['scroll_timeline_number']); ?></span></div></div>
                            <div class="scroll-timeline-info">
                                <div class="scroll-timeline-subheading"><?php echo esc_html($item['scroll_timeline_subheading']); ?></div>
                                <h3 class="scroll-timeline-heading"><?php echo esc_html($item['scroll_timeline_heading']); ?></h3>
                                <div class="scroll-timeline-desc">
                                    <?php echo do_shortcode($item['scroll_timeline_content']); ?>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
            <div class="timeline-line"></div>
        </div>
        <?php
    }
    private function render_image($settings, $item) {
        if (!empty($item['timeline_image']['url'])) :
            ?>
            <?php
            $item['timeline_image_size']             = $settings['timeline_image_size'];
            $item['timeline_image_custom_dimension'] = $settings['timeline_image_custom_dimension'];
            echo Group_Control_Image_Size::get_attachment_image_html($item, 'timeline_image');
            ?>
        <?php
        endif;
    }
}

$widgets_manager->register(new Rebuilto_Elementor_Scroll_Timeline());
