<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;

class Rebuilto_Elementor_Team_Box extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve teambox widget name.
     *
     * @return string Widget name.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'rebuilto-team-box';
    }

    /**
     * Get widget title.
     *
     * Retrieve teambox widget title.
     *
     * @return string Widget title.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Rebuilto Team Box', 'rebuilto');
    }

    /**
     * Get widget icon.
     *
     * Retrieve teambox widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-person';
    }

    public function get_script_depends() {
        return ['magnific-popup','rebuilto-elementor-team-box', 'rebuilto-elementor-swiper'];
    }

    public function get_style_depends() {
        return ['magnific-popup'];
    }

    public function get_categories() {
        return array('rebuilto-addons');
    }

    /**
     * Register teambox widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'section_team',
            [
                'label' => esc_html__('Team', 'rebuilto'),
            ]
        );
        $repeater = new Repeater();


        $repeater->add_control(
            'teambox_image',
            [
                'label'      => esc_html__('Choose Image', 'rebuilto'),
                'default'    => [
                    'url' => Elementor\Utils::get_placeholder_image_src(),
                ],
                'type'       => Controls_Manager::MEDIA,
                'show_label' => false,
            ]
        );

        $repeater->add_control(
            'teambox_name',
            [
                'label'   => esc_html__('Name', 'rebuilto'),
                'default' => 'John Doe',
                'type'    => Controls_Manager::TEXT,
            ]
        );

        $repeater->add_control(
            'teambox_job',
            [
                'label'   => esc_html__('Job', 'rebuilto'),
                'default' => 'Designer',
                'type'    => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'teambox_phone',
            [
                'label'   => esc_html__('Phone', 'rebuilto'),
                'default' => '(308) 555-0121',
                'type'    => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'teambox_email',
            [
                'label'   => esc_html__('Email', 'rebuilto'),
                'default' => 'robert@example.com',
                'type'    => Controls_Manager::TEXT,
            ]
        );

        $repeater->add_control(
            'teambox_description',
            [
                'label'       => esc_html__('Description', 'rebuilto'),
                'type'        => Controls_Manager::WYSIWYG,
                'default'     => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'rebuilto'),
                'placeholder' => esc_html__('Enter your description', 'rebuilto'),
                'separator'   => 'none',
                'rows'        => 5,
            ]
        );

        $repeater->add_control(
            'facebook',
            [
                'label'       => esc_html__('Facebook', 'rebuilto'),
                'type'        => Controls_Manager::URL,
                'label_block' => false,
            ]
        );

        $repeater->add_control(
            'instagram',
            [
                'label'       => esc_html__('Instagram', 'rebuilto'),
                'type'        => Controls_Manager::URL,
                'label_block' => false,
            ]
        );

        $repeater->add_control(
            'youtube',
            [
                'label'       => esc_html__('Youtube', 'rebuilto'),
                'type'        => Controls_Manager::URL,
                'label_block' => false,
            ]
        );

        $repeater->add_control(
            'twitter',
            [
                'label'       => esc_html__('Twitter', 'rebuilto'),
                'type'        => Controls_Manager::URL,
                'label_block' => false,
            ]
        );

        $repeater->add_control(
            'pinterest',
            [
                'label'       => esc_html__('Pinterest', 'rebuilto'),
                'type'        => Controls_Manager::URL,
                'label_block' => false,
            ]
        );
        $this->add_control(
            'teambox',
            [
                'label'       => esc_html__('Items', 'rebuilto'),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{{ name }}}',
            ]
        );

        $this->add_control(
            'teambox_layout',
            [
                'label'              => esc_html__('Layout', 'rebuilto'),
                'type'               => Controls_Manager::SELECT,
                'default'            => '1',
                'options'            => [
                    '1' => esc_html__('Layout 1', 'rebuilto'),
                    '2' => esc_html__('Layout 2', 'rebuilto'),
                    '3' => esc_html__('Layout 3', 'rebuilto'),
                ],
                'frontend_available' => true,
                'render_type'        => 'template',
                'prefix_class'       => 'teambox-layout-',
            ]
        );

        $this->add_group_control(
            Elementor\Group_Control_Image_Size::get_type(),
            [
                'name'      => 'teambox_image',
                'default'   => 'full',
                'separator' => 'none',
            ]
        );

        $this->add_responsive_control(
            'column',
            [
                'label'     => esc_html__('Columns', 'rebuilto'),
                'type'      => \Elementor\Controls_Manager::SELECT,
                'default'   => 1,
                'options'   => [1 => 1, 2 => 2, 3 => 3, 4 => 4],
                'selectors' => [
                    '{{WRAPPER}} .d-grid' => 'grid-template-columns: repeat({{VALUE}}, 1fr)',
                ],
            ]
        );

        $this->add_responsive_control(
            'teambox_gutter',
            [
                'label'      => esc_html__('Gutter', 'rebuilto'),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .d-grid' => 'grid-gap:{{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render teambox widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        if (empty($settings['teambox'])) {
            return;
        }

        $this->add_render_attribute('wrapper', 'class', 'elementor-teambox-item-wrapper');
        $this->add_render_attribute('row', 'class', 'layout-' . esc_attr($settings['teambox_layout']));
        $this->add_render_attribute('row', 'class', 'd-grid');
        $this->add_render_attribute('item', 'class', 'elementor-teambox-item grid-item');
        $slide_html = '';
        $image_html = '';
        ?>

        <div <?php $this->print_render_attribute_string('wrapper'); ?>>
            <div class="elementor-teambox-wrapper-inner">
                <div <?php $this->print_render_attribute_string('row'); ?>>
                    <?php foreach ($settings['teambox'] as $index => $teambox): ?>
                        <div <?php $this->print_render_attribute_string('item'); ?> data-goto="<?php echo esc_attr($index); ?>">
                            <div class="teambox-item-inner">
                                <?php
                                if ($settings['teambox_layout'] !== '3') {
                                    $this->render_image($settings, $teambox);
                                }
                                ?>
                                <div class="team-content">
                                    <div class="team-content-header">
                                        <?php if ($teambox['teambox_job']) { ?>
                                            <div class="team-job heading sigma"><?php echo esc_html($teambox['teambox_job']); ?></div>
                                        <?php } ?>
                                        <?php
                                        echo '<div class="team-name heading gamma">' . esc_html($teambox['teambox_name']) . '</div>';
                                        ?>
                                    </div>
                                    <?php if ($teambox['teambox_description']) { ?>
                                        <div class="team-description"><?php echo wp_kses_post($teambox['teambox_description']); ?></div>
                                    <?php } ?>
                                </div>
                            </div>
                        </div>
                        <?php
                        ob_start();
                        ?>
                        <div class="swiper-slide">
                            <div class="team-slide">
                                <svg class="icon-slide" width="461" height="238" viewBox="0 0 461 238" fill="none" xmlns="http://www.w3.org/2000/svg">
                                    <path fill-rule="evenodd" clip-rule="evenodd" d="M369.5 0C246.339 164 123.161 328 0 492H112.864C198.514 377.189 283.885 262.782 369.447 148.129L369.517 148.217L369.588 148.129C455.133 262.782 540.503 377.172 626.171 492H739C615.839 328 492.661 164 369.5 0Z" fill="#FF792D"/>
                                </svg>
                                <div class="team-content">
                                    <?php if ($teambox['teambox_job']) { ?>
                                        <div class="team-job heading sigma"><?php echo esc_html($teambox['teambox_job']); ?></div>
                                    <?php } ?>
                                    <?php
                                    echo '<div class="team-name heading alpha">' . esc_html($teambox['teambox_name']) . '</div>';
                                    ?>
                                    <div class="team-infor-wrap">
                                        <div class="team-infor">
                                            <?php if ($teambox['teambox_phone']) { ?>
                                                <span><?php echo esc_html($teambox['teambox_phone']); ?></span>
                                            <?php } ?>
                                            <?php if ($teambox['teambox_email']) { ?>
                                                <span><?php echo esc_html($teambox['teambox_email']); ?></span>
                                            <?php } ?>
                                        </div>
                                        <div class="team-icon-socials">
                                            <?php foreach ($this->get_socials() as $key => $social): ?>
                                                <?php if (!empty($teambox[$key]['url'])) : ?>
                                                    <a class="heading sigma" href="<?php echo esc_url($teambox[$key]['url']) ?>">
                                                        <?php echo esc_html($social); ?>
                                                    </a>
                                                <?php endif; ?>
                                            <?php endforeach; ?>
                                        </div>
                                    </div>
                                    <div class="line"></div>
                                    <?php if ($teambox['teambox_description']) { ?>
                                        <div class="team-description"><?php echo wp_kses_post($teambox['teambox_description']); ?></div>
                                    <?php } ?>


                                </div>
                                <?php $this->render_image($settings, $teambox); ?>

                            </div>
                        </div>
                        <?php
                        $slide_html .= ob_get_clean();
                        if ($settings['teambox_layout'] == '3') {
                            ob_start();
                            ?>
                            <div class="swiper-slide">
                                <?php $this->render_image($settings, $teambox); ?>
                            </div>
                            <?php
                            $image_html .= ob_get_clean();
                        }

                    endforeach; ?>
                </div>
                <?php
                if ($settings['teambox_layout'] == '3') {
                    ?>
                    <div class="team-effect">
                        <div class="rebuilto-swiper swiper swiper-team-effect">
                            <div class="swiper-wrapper">
                                <?php printf('%s', $image_html); ?>
                            </div>
                        </div>
                    </div>
                    <?php
                }
                ?>
                <div class="team-popup mfp-hide" id="<?php echo esc_attr('team-popup-' . $this->get_id()); ?>">
                    <div class="team-popup-inner">
                        <button class="team-popup-close mfp-close">
                            <svg class="close-icon" xmlns="http://www.w3.org/2000/svg" width="23.691" height="22.723" viewBox="0 0 23.691 22.723">
                                <g transform="translate(-126.154 -143.139)">
                                    <line x2="23" y2="22" transform="translate(126.5 143.5)" fill="none" stroke="CurrentColor" stroke-width="2"></line>
                                    <path d="M0,22,23,0" transform="translate(126.5 143.5)" fill="none" stroke="CurrentColor" stroke-width="2"></path>
                                </g>
                            </svg>
                        </button>
                        <div class="rebuilto-swiper-wrap">
                            <div class="rebuilto-swiper swiper swiper-team-popup">
                                <div class="swiper-wrapper">
                                    <?php printf('%s', $slide_html); ?>
                                </div>
                                <div class="swiper-pagination"></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    private function render_image($settings, $teambox) {
        if (!empty($teambox['teambox_image']['url'])) :
            ?>
            <div class="team-image">
                <div class="team-image-inner">
                    <?php
                    $teambox['teambox_image_size']             = $settings['teambox_image_size'];
                    $teambox['teambox_image_custom_dimension'] = $settings['teambox_image_custom_dimension'];
                    echo Group_Control_Image_Size::get_attachment_image_html($teambox, 'teambox_image');
                    ?>
                </div>
            </div>
        <?php
        endif;
    }

    private function get_socials() {
        return array(
            'facebook'  => esc_html__('FB', 'rebuilto'),
            'instagram' => esc_html__('IN', 'rebuilto'),
            'youtube'   => esc_html__('YT', 'rebuilto'),
            'twitter'   => esc_html__('TW', 'rebuilto'),
            'pinterest' => esc_html__('PT', 'rebuilto'),
        );
    }

}

$widgets_manager->register(new Rebuilto_Elementor_Team_Box());
