<?php
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class Rebuilto_Project
 */
class Rebuilto_Project {
    public $post_type = 'rebuilto_project';
    public $taxonomy  = 'rebuilto_project_cat';
    static $instance;

    public static function getInstance() {
        if (!isset(self::$instance) && !(self::$instance instanceof Rebuilto_Project)) {
            self::$instance = new Rebuilto_Project();
        }

        return self::$instance;
    }

    public function __construct() {
        add_action('init', [$this, 'create_post_type']);
        add_action('init', [$this, 'create_taxonomy']);
        add_action('cmb2_admin_init', array($this, 'create_meta_box'));
        add_action('cmb2_admin_init', [$this, 'rebuilto_register_theme_options_metabox']);

        add_action('pre_get_posts', [$this, 'posts_per_page']);

    }

    /**
     * @return void
     */
    public function create_post_type() {

        $labels = array(
            'name'               => esc_html__('Projects', 'rebuilto'),
            'singular_name'      => esc_html__('Project', 'rebuilto'),
            'add_new'            => esc_html__('Add New Project', 'rebuilto'),
            'add_new_item'       => esc_html__('Add New Project', 'rebuilto'),
            'edit_item'          => esc_html__('Edit Project', 'rebuilto'),
            'new_item'           => esc_html__('New Project', 'rebuilto'),
            'view_item'          => esc_html__('View Project', 'rebuilto'),
            'search_items'       => esc_html__('Search Projects', 'rebuilto'),
            'not_found'          => esc_html__('No Projects found', 'rebuilto'),
            'not_found_in_trash' => esc_html__('No Projects found in Trash', 'rebuilto'),
            'parent_item_colon'  => esc_html__('Parent Project:', 'rebuilto'),
            'menu_name'          => esc_html__('Projects', 'rebuilto'),
        );

        $labels     = apply_filters('rebuilto_project_labels', $labels);
        $slug_field = apply_filters('rebuilto_project_slug', 'projects');

        register_post_type($this->post_type,
            array(
                'labels'        => $labels,
                'supports'      => array('title', 'editor', 'thumbnail', 'excerpt'),
                'public'        => true,
                'has_archive'   => true,
                'rewrite'       => array('slug' => $slug_field),
                'menu_position' => 5,
                'categories'    => array(),
            )
        );
    }

    public function create_taxonomy() {
        $labels         = array(
            'name'              => __('Categories', 'rebuilto'),
            'singular_name'     => __('Category', 'rebuilto'),
            'search_items'      => __('Search Category', 'rebuilto'),
            'all_items'         => __('All Categories', 'rebuilto'),
            'parent_item'       => __('Parent Category', 'rebuilto'),
            'parent_item_colon' => __('Parent Category:', 'rebuilto'),
            'edit_item'         => __('Edit Category', 'rebuilto'),
            'update_item'       => __('Update Category', 'rebuilto'),
            'add_new_item'      => __('Add New Category', 'rebuilto'),
            'new_item_name'     => __('New Category Name', 'rebuilto'),
            'menu_name'         => __('Categories', 'rebuilto'),
        );
        $labels         = apply_filters('rebuilto_postype_project_cat_labels', $labels);
        $slug_cat_field = apply_filters('slug_category_project', 'category-project');
        $args           = array(
            'hierarchical'      => true,
            'labels'            => $labels,
            'show_ui'           => true,
            'show_admin_column' => true,
            'query_var'         => true,
            'show_in_nav_menus' => true,
            'rewrite'           => array('slug' => $slug_cat_field)
        );
        // Now register the taxonomy
        register_taxonomy($this->taxonomy, array($this->post_type), $args);
    }

    public function create_meta_box() {
        $prefix = 'rebuilto_';
        $cmb2   = new_cmb2_box(array(
            'id'           => $prefix . 'project_meta',
            'title'        => __('Infomation', 'rebuilto'),
            'object_types' => array('rebuilto_project'),
        ));

        $group_field_id = $cmb2->add_field(array(
            'id'      => 'project_meta_repeat',
            'type'    => 'group',
            'options' => array(
                'group_title'   => __('Entry {#}', 'rebuilto'),
                'add_button'    => __('Add Another Entry', 'rebuilto'),
                'remove_button' => __('Remove Entry', 'rebuilto'),
                'sortable'      => true,
            ),
        ));

        $cmb2->add_group_field($group_field_id, array(
            'name' => __('Title', 'rebuilto'),
            'id'   => 'title',
            'type' => 'text',
        ));

        $cmb2->add_group_field($group_field_id, array(
            'name' => __('Description', 'rebuilto'),
            'id'   => 'description',
            'type' => 'text',
        ));

        $cmb2->add_group_field($group_field_id, array(
            'name'        => __('Show in archive', 'rebuilto'),
            'id'          => 'show_archive',
            'description' => __('If you select this option, the above information will be displayed outside the archive page', 'rebuilto'),
            'type'        => 'checkbox',
        ));

    }

    public function rebuilto_register_theme_options_metabox() {

        /**
         * Registers options page menu item and form.
         */
        $cmb2 = new_cmb2_box(array(
            'id'           => 'rebuilto_project_archive',
            'title'        => esc_html__('Projects Setting', 'rebuilto'),
            'object_types' => array('options-page'),
            'option_key'   => 'rebuilto_project_archive',
            'position'     => 8,
        ));

        $cmb2->add_field(array(
            'name' => esc_html__('Archive description', 'rebuilto'),
            'id'   => 'rebuilto_project-content',
            'type' => 'wysiwyg',
        ));

        $cmb2->add_field(array(
            'name'             => esc_html__('Archive Style', 'rebuilto'),
            'id'               => 'archive_style',
            'type'             => 'select',
            'show_option_none' => true,
            'default'          => 'style-1',
            'options'          => array(
                'style-1' => esc_html__('Style 1', 'rebuilto'),
                'style-5' => esc_html__('Style 2', 'rebuilto'),
                'style-3' => esc_html__('Style 3', 'rebuilto'),
            ),
        ));

        $cmb2->add_field(array(
            'name'             => esc_html__('Columns Desktop', 'rebuilto'),
            'id'               => 'columns_desktop',
            'type'             => 'select',
            'show_option_none' => true,
            'default'          => '2',
            'options'          => array(
                '1' => '1',
                '2' => '2',
                '3' => '3',
            ),
        ));
        $cmb2->add_field(array(
            'name'             => esc_html__('Columns Tablet', 'rebuilto'),
            'id'               => 'columns_tablet',
            'type'             => 'select',
            'show_option_none' => true,
            'default'          => '2',
            'options'          => array(
                '1' => '1',
                '2' => '2',
                '3' => '3',
            ),
        ));

        $cmb2->add_field(array(
            'name'             => esc_html__('Columns Mobile', 'rebuilto'),
            'id'               => 'columns_mobile',
            'type'             => 'select',
            'show_option_none' => true,
            'default'          => '1',
            'options'          => array(
                '1' => '1',
                '2' => '2',
                '3' => '3',
            ),
        ));

        $cmb2->add_field(array(
            'name'    => __('Gutter (px)', 'rebuilto'),
            'id'      => 'gutter',
            'type'    => 'text',
            'default' => 30,
        ));

        $cmb2->add_field(array(
            'name'    => __('Posts Per Page', 'rebuilto'),
            'id'      => 'posts_per_page',
            'type'    => 'text',
            'default' => 12,
        ));
    }

    public function posts_per_page($query) {
        $options        = get_option('rebuilto_project_archive');
        $posts_per_page = 12;
        if ($options && is_array($options)) {
            $posts_per_page          = isset($options['posts_per_page']) ? $options['posts_per_page'] : 12;
        }
        if (is_admin() || !$query->is_main_query()) {
            return;
        }

        if (is_post_type_archive('rebuilto_project') || is_tax('rebuilto_project_cat')) {
            $query->set('posts_per_page', $posts_per_page);
        }
    }

}

Rebuilto_Project::getInstance();
