<?php
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class Rebuilto_Service
 */
class Rebuilto_Service {
    public $post_type = 'rebuilto_service';
    static $instance;

    public static function getInstance() {
        if (!isset(self::$instance) && !(self::$instance instanceof Rebuilto_Service)) {
            self::$instance = new Rebuilto_Service();
        }

        return self::$instance;
    }

    public function __construct() {
        add_action('init', [$this, 'create_post_type']);
        if (rebuilto_is_cmb2_activated()) {
            add_action('init', [$this, 'setup_metabox']);
        }
    }

    public function setup_metabox() {
        add_action('cmb2_admin_init', [$this, 'metabox_service']);
    }

    public function metabox_service() {
        $cmb2 = new_cmb2_box(array(
            'id'           => 'rebuilto_service_setting',
            'title'        => esc_html__('Infomation', 'rebuilto'),
            'object_types' => array('rebuilto_service'),
        ));

        $cmb2->add_field(array(
            'name'       => esc_html__('Service Icon', 'rebuilto'),
            'id'         => 'service_icon_class',
            'type'       => 'file',
            'options'    => array(
                'url' => true,
            ),
        ));
    }


    /**
     * @return void
     */
    public function create_post_type() {

        $labels = array(
            'name'               => esc_html__('Services', 'rebuilto'),
            'singular_name'      => esc_html__('Service', 'rebuilto'),
            'add_new'            => esc_html__('Add New Service', 'rebuilto'),
            'add_new_item'       => esc_html__('Add New Service', 'rebuilto'),
            'edit_item'          => esc_html__('Edit Service', 'rebuilto'),
            'new_item'           => esc_html__('New Service', 'rebuilto'),
            'view_item'          => esc_html__('View Service', 'rebuilto'),
            'search_items'       => esc_html__('Search Services', 'rebuilto'),
            'not_found'          => esc_html__('No Services found', 'rebuilto'),
            'not_found_in_trash' => esc_html__('No Services found in Trash', 'rebuilto'),
            'parent_item_colon'  => esc_html__('Parent Service:', 'rebuilto'),
            'menu_name'          => esc_html__('Services', 'rebuilto'),
        );

        $labels     = apply_filters('rebuilto_service_labels', $labels);
        $slug_field = apply_filters('rebuilto_service_slug', 'services');

        register_post_type($this->post_type,
            array(
                'labels'        => $labels,
                'supports'      => array('title', 'editor', 'thumbnail', 'excerpt'),
                'public'        => true,
                'has_archive'   => false,
                'rewrite'       => array('slug' => $slug_field),
                'menu_position' => 5,
            )
        );
    }

}

Rebuilto_Service::getInstance();
